@@ -1,7 +1,7 @@
 r"""
 .. _powerlaw-spectral-model:
 
-Power Law Spectral Model
+Power law spectral model
 ========================
 
 This model parametrises a power law spectrum.
@@ -22,11 +22,13 @@ from astropy import units as u
 import matplotlib.pyplot as plt
 from gammapy.modeling.models import Models, PowerLawSpectralModel, SkyModel
 
-energy_range = [0.1, 100] * u.TeV
+energy_bounds = [0.1, 100] * u.TeV
 model = PowerLawSpectralModel(
-    index=2, amplitude="1e-12 TeV-1 cm-2 s-1", reference=1 * u.TeV,
+    index=2,
+    amplitude="1e-12 TeV-1 cm-2 s-1",
+    reference=1 * u.TeV,
 )
-model.plot(energy_range)
+model.plot(energy_bounds)
 plt.grid(which="both")
 
 # %%
