@@ -28,7 +28,7 @@ Proposed approach
 -----------------
 
 The first step here, as in most analysis with DL3 data, is to create
-reduced datasets. For this, we will use the `Analysis` class to create
+reduced datasets. For this, we will use the `~gammapy.analysis.Analysis` class to create
 a single set of stacked maps with a single bin in energy (thus, an
 *image* which behaves as a *cube*). This, we will then model with a
 spatial model of our choice, while keeping the spectral model fixed to
@@ -49,13 +49,6 @@ import matplotlib.pyplot as plt
 from IPython.display import display
 from gammapy.analysis import Analysis, AnalysisConfig
 
-######################################################################
-# Check setup
-# -----------
-from gammapy.utils.check import check_tutorials_setup
-
-check_tutorials_setup()
-
 
 ######################################################################
 # Creating the config file
@@ -112,11 +105,10 @@ print(config)
 
 
 ######################################################################
-# We now use the config file and create a single `MapDataset` containing
+# We now use the config file and create a single `~gammapy.datasets.MapDataset` containing
 # `counts`, `background`, `exposure`, `psf` and `edisp` maps.
 #
 
-# %%time
 analysis = Analysis(config)
 analysis.get_observations()
 analysis.get_datasets()
