@@ -32,15 +32,8 @@ from gammapy.modeling.models import (
     PointSpatialModel,
     SkyModel,
 )
-
-######################################################################
-# Check setup
-# -----------
-from gammapy.utils.check import check_tutorials_setup
 from gammapy.visualization import plot_distribution
 
-check_tutorials_setup()
-
 
 ######################################################################
 # Analysis configuration
@@ -98,10 +91,10 @@ print(config)
 # future reference.
 #
 
-config_stack = config.copy(deep=True)
+config_stack = config.model_copy(deep=True)
 config_stack.datasets.stack = True
 
-config_joint = config.copy(deep=True)
+config_joint = config.model_copy(deep=True)
 config_joint.datasets.stack = False
 
 # To prevent unnecessary cluttering, we write it in a separate folder.
@@ -127,7 +120,6 @@ config_stacked = AnalysisConfig.read(path=path / "config_stack.yaml")
 
 analysis_stacked = Analysis(config_stacked)
 
-# %%time
 # select observations:
 analysis_stacked.get_observations()
 
@@ -192,14 +184,14 @@ plt.show()
 
 ######################################################################
 # To perform the fit on a restricted energy range, we can create a
-# specific *mask*. On the dataset, the `mask_fit` is a `Map` sharing
-# the same geometry as the `MapDataset` and containing boolean data.
+# specific *mask*. On the dataset, the `mask_fit` is a `~gammapy.maps.Map` sharing
+# the same geometry as the `~gammapy.datasets.MapDataset` and containing boolean data.
 #
 # To create a mask to limit the fit within a restricted energy range, one
 # can rely on the `~gammapy.maps.Geom.energy_mask()` method.
 #
 # For more details on masks and the techniques to create them in gammapy,
-# please checkout the dedicated :doc:`/tutorials/api/mask_maps` tutorial.
+# please checkout the dedicated :doc:`/tutorials/details/mask_maps` tutorial.
 #
 
 dataset_stacked.mask_fit = dataset_stacked.counts.geom.energy_mask(
@@ -229,14 +221,15 @@ models_stacked = Models([model, bkg_model])
 
 dataset_stacked.models = models_stacked
 
-# %%time
 fit = Fit(optimize_opts={"print_level": 1})
 result = fit.run(datasets=[dataset_stacked])
 
 
 ######################################################################
-# Fit quality assessment and model residuals for a `MapDataset`
-# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+# .. _mapdataset_fit_quality:
+#
+# Fit quality assessment and model residuals for a `~gammapy.datasets.MapDataset`
+# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 
 
@@ -256,7 +249,7 @@ display(models_stacked.to_parameters_table())
 
 ######################################################################
 # A quick way to inspect the model residuals is using the function
-# `~MapDataset.plot_residuals_spatial()`. This function computes and
+# `~gammapy.datasets.MapDataset.plot_residuals_spatial()`. This function computes and
 # plots a residual image (by default, the smoothing radius is `0.1 deg`
 # and `method=diff`, which corresponds to a simple `data - model`
 # plot):
@@ -266,7 +259,7 @@ plt.show()
 
 
 ######################################################################
-# The more general function `~MapDataset.plot_residuals()` can also
+# The more general function `~gammapy.datasets.MapDataset.plot_residuals()` can also
 # extract and display spectral residuals in a region:
 #
 
@@ -280,11 +273,13 @@ plt.show()
 
 ######################################################################
 # This way of accessing residuals is quick and handy, but comes with
-# limitations. For example: - In case a fitting energy range was defined
-# using a `MapDataset.mask_fit`, it won’t be taken into account.
-# Residuals will be summed up over the whole reconstructed energy range -
-# In order to make a proper statistic treatment, instead of simple
-# residuals a proper residuals significance map should be computed
+# limitations. For example:
+#
+# - In case a fitting energy range was defined using a
+#   `~gammapy.datasets.MapDataset.mask_fit`, it won’t be taken into account.
+#   Residuals will be summed up over the whole reconstructed energy range
+# - In order to make a proper statistic treatment, instead of simple
+#   residuals a proper residuals significance map should be computed
 #
 # A more accurate way to inspect spatial residuals is the following:
 #
@@ -340,7 +335,6 @@ plt.show()
 # ~~~~~~~~~~~~~~
 #
 
-# %%time
 
 # Read the yaml file from disk
 config_joint = AnalysisConfig.read(path=path / "config_joint.yaml")
@@ -386,14 +380,15 @@ print(models_joint)
 # and set the new model
 analysis_joint.datasets.models = models_joint
 
-# %%time
 fit_joint = Fit()
 result_joint = fit_joint.run(datasets=analysis_joint.datasets)
 
 
 ######################################################################
-# Fit quality assessment and model residuals for a joint `Datasets`
-# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+# .. _dataset_fit_quality:
+#
+# Fit quality assessment and model residuals for a joint `~gammapy.datasets.Datasets`
+# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 
 
@@ -412,24 +407,23 @@ print(models_joint)
 
 
 ######################################################################
-# Since the joint dataset is made of multiple datasets, we can either: -
-# Look at the residuals for each dataset separately. In this case, we can
-# directly refer to the section
-# `Fit quality and model residuals for a MapDataset` in this notebook -
-# Or, look at a stacked residual map.
+# Since the joint dataset is made of multiple datasets, we can either:
+#
+# - Look at the residuals for each dataset separately. In this case, we can
+#   directly refer to the section :ref:`mapdataset_fit_quality`
+# - Or, look at a stacked residual map.
 #
 
 stacked = analysis_joint.datasets.stack_reduce()
 stacked.models = [model_joint]
 
-plt.figure()
 stacked.plot_residuals_spatial(vmin=-1, vmax=1)
+plt.show()
 
 
 ######################################################################
 # Then, we can access the stacked model residuals as previously shown in
-# the section `Fit quality and model residuals for a MapDataset` in this
-# notebook.
+# the section :ref:`dataset_fit_quality`.
 #
 
 
@@ -470,14 +464,15 @@ plt.show()
 ######################################################################
 # .. image:: ../../_static/DC1_3d.png
 #
+#
 
 
 ######################################################################
 # Exercises
 # ---------
 #
-# -  Analyse the second source in the field of view: G0.9+0.1 and add it
-#    to the combined model.
-# -  Perform modeling in more details - Add diffuse component, get flux
-#    points.
+# - Analyse the second source in the field of view: G0.9+0.1 and add it
+#   to the combined model.
+# - Perform modeling in more details.
+# - Add diffuse component, get flux points.
 #
