@@ -22,15 +22,15 @@ event-sampler and how to obtain an output photon event list.
 The core of the event sampling lies into the Gammapy
 `~gammapy.datasets.MapDatasetEventSampler` class, which is based on
 the inverse cumulative distribution function `(Inverse
-CDF) <https://en.wikipedia.org/wiki/Cumulative_distribution_function#Inverse_distribution_function_(quantile_function)>`__. 
+CDF) <https://en.wikipedia.org/wiki/Cumulative_distribution_function#Inverse_distribution_function_(quantile_function)>`__.
 
 The `~gammapy.datasets.MapDatasetEventSampler` takes in input a
 `~gammapy.datasets.Dataset` object containing the spectral, spatial
 and temporal properties of the source(s) of interest.
 
 The `~gammapy.datasets.MapDatasetEventSampler` class evaluates the map
-of predicted counts (`npred`) per bin of the given Sky model, and the
-`npred` map is then used to sample the events. In particular, the
+of predicted counts (``npred``) per bin of the given Sky model, and the
+``npred`` map is then used to sample the events. In particular, the
 output of the event-sampler will be a set of events having information
 about their true coordinates, true energies and times of arrival.
 
@@ -86,7 +86,6 @@ from pathlib import Path
 import numpy as np
 import astropy.units as u
 from astropy.coordinates import Angle, SkyCoord
-from astropy.io import fits
 from astropy.time import Time
 from regions import CircleSkyRegion
 import matplotlib.pyplot as plt
@@ -113,15 +112,8 @@ from gammapy.modeling.models import (
 )
 
 ######################################################################
-# Check setup
-# -----------
-from gammapy.utils.check import check_tutorials_setup
-
-check_tutorials_setup()
-
-######################################################################
-# Define an Observation
-# ---------------------
+# Define an `~gammapy.data.Observation`
+# -------------------------------------
 #
 # You can firstly create a `~gammapy.data.Observations` object that
 # contains the pointing position, the GTIs and the IRF you want to
@@ -141,7 +133,7 @@ pointing = FixedPointingInfo(
     fixed_icrs=SkyCoord(0.0, 0.0, frame="galactic", unit="deg").icrs,
 )
 livetime = 1 * u.hr
-location = observatory_locations["cta_south"]
+location = observatory_locations["ctao_south"]
 
 
 irfs = load_irf_dict_from_file(path / irf_filename)
@@ -160,12 +152,12 @@ observation = Observation.create(
 print(observation)
 
 ######################################################################
-# Define the MapDataset
-# ---------------------
+# Define the `~gammapy.datasets.MapDataset`
+# -----------------------------------------
 #
 # Let’s generate the `~gammapy.datasets.Dataset` object (for more info
 # on `~gammapy.datasets.Dataset` objects, please checkout
-# :doc:`/tutorials/api/datasets` tutorial):
+# :doc:`/tutorials/details/datasets` tutorial):
 # we define the energy axes (true and reconstructed), the migration axis
 # and the geometry of the observation.
 #
@@ -200,11 +192,10 @@ geom = WcsGeom.create(
 ######################################################################
 # In the following, the dataset is created by selecting the effective
 # area, background model, the PSF and the Edisp from the IRF. The dataset
-# thus produced can be saved into a FITS file just using the `write()`
-# function. We put it into the `evt_sampling` sub-folder:
+# thus produced can be saved into a FITS file just using the ``write()``
+# function. We put it into the ``event_sampling`` sub-folder:
 #
 
-# %%time
 empty = MapDataset.create(
     geom,
     energy_axis_true=energy_axis_true,
@@ -218,8 +209,8 @@ Path("event_sampling").mkdir(exist_ok=True)
 dataset.write("./event_sampling/dataset.fits", overwrite=True)
 
 ######################################################################
-# Define the Sky model: a point-like source
-# -----------------------------------------
+# Define the `~gammapy.modeling.models.SkyModel`: a point-like source
+# -------------------------------------------------------------------
 #
 # Now let’s define a sky model for a point-like source centered 0.5
 # deg far from the Galactic Center and with a power-law spectrum. We then
@@ -268,7 +259,6 @@ print(dataset.models)
 # data information.
 #
 
-# %%time
 sampler = MapDatasetEventSampler(random_state=0)
 events = sampler.run(dataset, observation)
 
@@ -300,16 +290,15 @@ plt.show()
 events.table.meta["OBJECT"] = dataset.models[0].name
 
 ######################################################################
-# Let’s write the event list and its GTI extension to a FITS file. We make
-# use of `fits` library in `astropy`:
+# Let’s write the event list and its GTI extension to a FITS file, adopting
+# the `observation` functions. We firstly link the `events` to the `observation`
+# objects and then we write it into a fits file:
 #
 
-primary_hdu = fits.PrimaryHDU()
-hdu_evt = fits.BinTableHDU(events.table)
-hdu_gti = fits.BinTableHDU(dataset.gti.table, name="GTI")
-hdu_all = fits.HDUList([primary_hdu, hdu_evt, hdu_gti])
-hdu_all.writeto("./event_sampling/events_0001.fits", overwrite=True)
-
+observation.events = events
+observation.write(
+    "./event_sampling/events_0001.fits", include_irfs=False, overwrite=True
+)
 
 ######################################################################
 # Time variable source using a lightcurve
@@ -370,7 +359,6 @@ print(dataset.models)
 # And now, let’s simulate the variable source:
 #
 
-# %%time
 sampler = MapDatasetEventSampler(random_state=0)
 events = sampler.run(dataset, observation)
 
@@ -379,8 +367,8 @@ print(f"Background events: {(events.table['MC_ID'] == 0).sum()}")
 
 ######################################################################
 # We can now inspect the properties of the simulated source. To do that,
-# we adopt the `select_region` function that extracts only the events
-# into a given `SkyRegion` of a `~gammapy.data.EventList` object:
+# we adopt the `~gammapy.data.EventList.select_region()` function that extracts only the events
+# into a given `~regions.Region` of a `~gammapy.data.EventList` object:
 #
 
 src_position = SkyCoord(0.0, 0.5, frame="galactic", unit="deg")
@@ -391,7 +379,7 @@ on_region = CircleSkyRegion(center=src_position, radius=on_region_radius)
 src_events = events.select_region(on_region)
 
 ######################################################################
-# Then we can have a quick look to the data with the `peek` function:
+# Then we can have a quick look to the data with the ``peek`` function:
 #
 
 src_events.peek()
@@ -435,7 +423,6 @@ dataset.models = models_diffuse
 print(dataset.models)
 
 
-# %%time
 sampler = MapDatasetEventSampler(random_state=0)
 events = sampler.run(dataset, observation)
 
@@ -458,7 +445,6 @@ plt.show()
 tstarts = Time("2020-01-01 00:00:00") + [1, 5, 7] * u.hr
 livetimes = [1, 1, 1] * u.hr
 
-# %%time
 n_obs = len(tstarts)
 irf_paths = [path / irf_filename] * n_obs
 events_paths = []
@@ -485,7 +471,7 @@ for idx, tstart in enumerate(tstarts):
 
 ######################################################################
 # You can now load the event list and the corresponding IRFs with
-# `DataStore.from_events_files`:
+# `~gammapy.data.DataStore.from_events_files()`:
 #
 
 path = Path("./event_sampling/")
