@@ -51,18 +51,11 @@ from gammapy.datasets import MapDataset
 from gammapy.estimators import FluxPoints, FluxProfileEstimator
 from gammapy.maps import RegionGeom
 from gammapy.modeling.models import PowerLawSpectralModel
-
-######################################################################
-# Check setup
-# -----------
-from gammapy.utils.check import check_tutorials_setup
 from gammapy.utils.regions import (
     make_concentric_annulus_sky_regions,
     make_orthogonal_rectangle_sky_regions,
 )
 
-check_tutorials_setup()
-
 
 ######################################################################
 # Read and Introduce Data
@@ -102,16 +95,16 @@ print(dataset.counts)
 # `~gammapy.utils.regions.make_orthogonal_rectangle_sky_regions`. The individual region bins
 # for the profile have a height of 3 deg and in total there are 31 bins.
 # Its starts from lon = 10 deg and goes to lon = 350 deg. In addition, we
-# have to specify the `wcs` to take into account possible projections
+# have to specify the ``wcs`` to take into account possible projections
 # effects on the region definition:
 #
 
 regions = make_orthogonal_rectangle_sky_regions(
-    start_pos=SkyCoord("10d", "0d", frame="galactic"),
-    end_pos=SkyCoord("350d", "0d", frame="galactic"),
+    start_pos=SkyCoord("9d", "0d", frame="galactic"),
+    end_pos=SkyCoord("351d", "0d", frame="galactic"),
     wcs=counts_image.geom.wcs,
     height="3 deg",
-    nbin=51,
+    nbin=49,
 )
 
 
@@ -134,7 +127,7 @@ plt.show()
 
 flux_profile_estimator = FluxProfileEstimator(
     regions=regions,
-    spectrum=PowerLawSpectralModel(index=2.3),
+    spectral_model=PowerLawSpectralModel(index=2.3),
     energy_edges=[10, 2000] * u.GeV,
     selection_optional=["ul"],
 )
@@ -154,7 +147,6 @@ print(flux_profile_estimator)
 # Now we can run the profile estimation and explore the results:
 #
 
-# %%time
 profile = flux_profile_estimator.run(datasets=dataset)
 
 print(profile)
@@ -162,8 +154,8 @@ print(profile)
 
 ######################################################################
 # We can see the flux profile is represented by a `~gammapy.estimators.FluxPoints` object
-# with a `projected-distance` axis, which defines the main axis the flux
-# profile is measured along. The `lon` and `lat` axes can be ignored.
+# with a ``projected-distance`` axis, which defines the main axis the flux
+# profile is measured along. The ``lon`` and ``lat`` axes can be ignored.
 #
 # Plotting Results
 # ~~~~~~~~~~~~~~~~
@@ -268,7 +260,7 @@ plt.show()
 
 flux_profile_estimator = FluxProfileEstimator(
     regions=regions,
-    spectrum=PowerLawSpectralModel(index=2.3),
+    spectral_model=PowerLawSpectralModel(index=2.3),
     energy_edges=[10, 100, 2000] * u.GeV,
     selection_optional=["ul", "scan"],
 )
