@@ -43,22 +43,11 @@ release 1.
 """
 
 import astropy.units as u
-from astropy.coordinates import SkyCoord
 
 # %matplotlib inline
 import matplotlib.pyplot as plt
 from IPython.display import display
 from gammapy.data import DataStore
-from gammapy.makers.utils import make_theta_squared_table
-from gammapy.maps import MapAxis
-
-######################################################################
-# Check setup
-# -----------
-from gammapy.utils.check import check_tutorials_setup
-from gammapy.visualization import plot_theta_squared_table
-
-check_tutorials_setup()
 
 
 ######################################################################
@@ -92,47 +81,30 @@ obs = data_store.obs(23523)
 # Select and peek events
 
 obs.events.select_offset([0, 2.5] * u.deg).peek()
+plt.show()
 
 ######################################################################
 # Peek the effective area
 
 obs.aeff.peek()
+plt.show()
 
 ######################################################################
 # Peek the energy dispersion
 
 obs.edisp.peek()
+plt.show()
 
 ######################################################################
 # Peek the psf
 obs.psf.peek()
+plt.show()
 
 ######################################################################
 # Peek the background rate
 obs.bkg.to_2d().plot()
 plt.show()
 
-######################################################################
-# Theta squared event distribution
-# --------------------------------
-#
-# As a quick look plot it can be helpful to plot the quadratic offset
-# (theta squared) distribution of the events.
-#
-
-position = SkyCoord(ra=83.63, dec=22.01, unit="deg", frame="icrs")
-theta2_axis = MapAxis.from_bounds(0, 0.2, nbin=20, interp="lin", unit="deg2")
-
-observations = data_store.get_observations([23523, 23526])
-theta2_table = make_theta_squared_table(
-    observations=observations,
-    position=position,
-    theta_squared_axis=theta2_axis,
-)
-
-plt.figure(figsize=(10, 5))
-plot_theta_squared_table(theta2_table)
-plt.show()
 
 ######################################################################
 # Exercises
@@ -153,3 +125,11 @@ plt.show()
 # tutorials and documentation apply to H.E.S.S. and CTAO or any other IACT
 # that provides DL3 data and IRFs in the standard format.
 #
+# You can see the following tutorials for more detailed analysis using H.E.S.S. data
+#
+# -  :doc:`/tutorials/starting/analysis_1`
+# -  :doc:`/tutorials/starting/analysis_2`
+# -  :doc:`/tutorials/analysis-1d/spectral_analysis`
+# -  :doc:`/tutorials/analysis-1d/extended_source_spectral_analysis`
+# -  :doc:`/tutorials/analysis-2d/ring_background`
+#
