@@ -1,9 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
-from numpy.testing import assert_allclose
 import numpy as np
+from numpy.testing import assert_allclose
 from astropy.units import Quantity
-from ...source import SNR, SNRTrueloveMcKee
+from gammapy.astro.source import SNR, SNRTrueloveMcKee
 
 t = Quantity([0, 1, 10, 100, 1000, 10000], "yr")
 snr = SNR()
