@@ -4,12 +4,16 @@ from gammapy.utils.registry import Registry
 from .core import SourceCatalog, SourceCatalogObject
 from .fermi import (
     SourceCatalog2FHL,
+    SourceCatalog2PC,
     SourceCatalog3FGL,
     SourceCatalog3FHL,
+    SourceCatalog3PC,
     SourceCatalog4FGL,
     SourceCatalogObject2FHL,
+    SourceCatalogObject2PC,
     SourceCatalogObject3FGL,
     SourceCatalogObject3FHL,
+    SourceCatalogObject3PC,
     SourceCatalogObject4FGL,
 )
 from .gammacat import SourceCatalogGammaCat, SourceCatalogObjectGammaCat
@@ -36,7 +40,9 @@ CATALOG_REGISTRY = Registry(
         SourceCatalog4FGL,
         SourceCatalog2FHL,
         SourceCatalog3FHL,
+        SourceCatalog3PC,
         SourceCatalog3HWC,
+        SourceCatalog2PC,
         SourceCatalog1LHAASO,
     ]
 )
@@ -53,6 +59,8 @@ __all__ = [
     "SourceCatalog3FHL",
     "SourceCatalog3HWC",
     "SourceCatalog4FGL",
+    "SourceCatalog2PC",
+    "SourceCatalog3PC",
     "SourceCatalogGammaCat",
     "SourceCatalogHGPS",
     "SourceCatalogLargeScaleHGPS",
@@ -64,6 +72,8 @@ __all__ = [
     "SourceCatalogObject3FHL",
     "SourceCatalogObject3HWC",
     "SourceCatalogObject4FGL",
+    "SourceCatalogObject2PC",
+    "SourceCatalogObject3PC",
     "SourceCatalogObjectGammaCat",
     "SourceCatalogObjectHGPS",
     "SourceCatalogObjectHGPSComponent",
