@@ -47,15 +47,27 @@ class SourceCatalogObject:
     it doesn't hold a reference back to it, except for a key
     ``_row_index`` of type ``int`` that links to the catalog table
     row the source information comes from.
+
+    Parameters
+    ----------
+    data : dict
+        Dictionary of data from a catalog for a given source.
+    data_extended : dict
+        Dictionary of data from a catalog for a given source in the case where the
+        catalog contains an extended sources table (Fermi-LAT).
+    data_spectral : dict
+        Dictionary of data from a catalof for a given source in the case where the
+        catalog contains a spectral table (Fermi-LAT 2PC and 3PC).
     """
 
     _source_name_key = "Source_Name"
     _row_index_key = "_row_index"
 
-    def __init__(self, data, data_extended=None):
+    def __init__(self, data, data_extended=None, data_spectral=None):
         self.data = Bunch(**data)
         if data_extended:
             self.data_extended = Bunch(**data_extended)
+        self.data_spectral = Bunch(**data_spectral) if data_spectral else None
 
     def _repr_html_(self):
         try:
@@ -257,18 +269,42 @@ class SourceCatalog(abc.ABC):
             name_extended = data["Source_Name"].strip()
         else:
             name_extended = None
+
+        name_spectral = self._get_name_spectral(data)
+
         try:
-            idx = self._lookup_extended_source_idx[name_extended]
+            idx = self._lookup_additional_table(
+                self.extended_sources_table[self._source_name_key]
+            )[name_extended]
             data_extended = table_row_to_dict(self.extended_sources_table[idx])
         except (KeyError, AttributeError):
             data_extended = None
 
-        source = self.source_object_class(data, data_extended)
+        try:
+            idx = self._lookup_additional_table(
+                self.spectral_table[self._get_source_name_key]
+            )[name_spectral]
+            data_spectral = table_row_to_dict(self.spectral_table[idx])
+        except (KeyError, AttributeError):
+            data_spectral = None
+
+        source = self.source_object_class(data, data_extended, data_spectral)
         return source
 
-    @lazyproperty
-    def _lookup_extended_source_idx(self):
-        names = [_.strip() for _ in self.extended_sources_table["Source_Name"]]
+    @property
+    def _get_source_name_key(self):
+        return self._source_name_key
+
+    def _get_name_spectral(self, data):
+        if "Source_name" in data:
+            name_spectral = data["Source_name"].strip()
+        else:
+            name_spectral = None
+        return name_spectral
+
+    def _lookup_additional_table(self, selected_table):
+        """"""
+        names = [_.strip() for _ in selected_table]
         idx = range(len(names))
         return dict(zip(names, idx))
 
@@ -293,6 +329,8 @@ def _skycoord_from_table(table):
         lon, lat, frame = "RA", "DEC", "icrs"
     elif {"ra", "dec"}.issubset(keys):
         lon, lat, frame = "ra", "dec", "icrs"
+    elif {"RAJD", "DECJD"}.issubset(keys):
+        lon, lat, frame = "RAJD", "DECJD", "icrs"
     else:
         raise KeyError("No column GLON / GLAT or RA / DEC or RAJ2000 / DEJ2000 found.")
 
