@@ -19,6 +19,7 @@ from gammapy.modeling.models import (
     Models,
     PowerLawSpectralModel,
     SkyModel,
+    GaussianPrior,
 )
 from gammapy.utils.random import get_random_state
 from gammapy.utils.regions import compound_region_to_regions
@@ -548,6 +549,15 @@ class TestSpectrumOnOff:
         assert regions[0].center.is_equivalent_frame(expected_regions[0].center)
         assert_allclose(regions[1].angle, expected_regions[1].angle)
 
+    def test_from_ogip_files_overwrite_name(self, tmp_path):
+        dataset = self.dataset.copy(name="test")
+        dataset.write(tmp_path / "test.fits")
+        new_dataset = SpectrumDatasetOnOff.read(tmp_path / "test.fits")
+        assert new_dataset.name == dataset.name
+
+        new_dataset = SpectrumDatasetOnOff.read(tmp_path / "test.fits", name="new_name")
+        assert new_dataset.name == "new_name"
+
     def test_to_from_ogip_files_no_mask(self, tmp_path):
         dataset = self.dataset.copy(name="test")
         dataset.mask_safe = None
@@ -566,7 +576,6 @@ class TestSpectrumOnOff:
         assert newdataset.counts.meta["ANCRFILE"] == "test_arf.fits.gz"
 
     def test_to_from_ogip_files_no_edisp(self, tmp_path):
-
         mask_safe = RegionNDMap.from_geom(self.on_counts.geom, dtype=bool)
         mask_safe.data += True
 
@@ -713,6 +722,16 @@ class TestSpectrumOnOff:
         assert_allclose(np.squeeze(grouped.acceptance), 4)
         assert_allclose(np.squeeze(grouped.acceptance_off), 40)
 
+    def test_spectrum_dataset_ogip_creation_metadata(self, tmp_path):
+        dataset = self.dataset.copy(name="test")
+        dataset.write(tmp_path / "test.fits", format="ogip")
+
+        for name in ["test.fits", "test_arf.fits", "test_bkg.fits", "test_rmf.fits"]:
+            with fits.open(tmp_path / name) as hdul:
+                for hdu in hdul[1:]:
+                    assert "CREATOR" in hdu.header
+                    assert "CREATED" in hdu.header
+
 
 @requires_data()
 class TestSpectralFit:
@@ -1216,3 +1235,35 @@ def test_stat_sum():
     dataset.mask_safe.data[0] = True
     with pytest.raises(AttributeError):
         dataset.stat_sum()
+
+
+@requires_data("gammapy-data")
+def test_priors():
+    datasets = Datasets()
+    obs_ids = [23523, 23526]
+
+    for obs_id in obs_ids:
+        filename = f"$GAMMAPY_DATA/joint-crab/spectra/hess/pha_obs{obs_id}.fits"
+        ds = SpectrumDatasetOnOff.read(filename)
+        datasets.append(ds)
+
+    spectral_model = PowerLawSpectralModel(
+        index=2.5, amplitude="3.8e-11 cm-2 s-1 TeV-1"
+    )
+    source_model = SkyModel(spectral_model=spectral_model, name="source")
+
+    datasets.models = [source_model]
+
+    stat_sum = datasets.stat_sum()
+
+    spectral_model.index.prior = GaussianPrior(
+        mu=spectral_model.index.value + 0.1, sigma=0.1
+    )
+
+    prior_stat_sum = spectral_model.index.prior_stat_sum()
+
+    stat_sum_with_priors = datasets.stat_sum()
+
+    assert_allclose(stat_sum, 87.928542, atol=1e-1)
+    # Here we check that the prior is applied only once
+    assert_allclose(stat_sum_with_priors, stat_sum + prior_stat_sum)
