@@ -41,7 +41,6 @@ REQUIRED_COLUMNS = {
     "e2dnde": ["e_ref", "e2dnde"],
     "flux": ["e_min", "e_max", "flux"],
     "eflux": ["e_min", "e_max", "eflux"],
-    # TODO: extend required columns
     "likelihood": [
         "e_min",
         "e_max",
@@ -61,7 +60,7 @@ OPTIONAL_QUANTITIES = {
     "e2dnde": ["e2dnde_err", "e2dnde_errp", "e2dnde_errn", "e2dnde_ul"],
     "flux": ["flux_err", "flux_errp", "flux_errn", "flux_ul", "flux_sensitivity"],
     "eflux": ["eflux_err", "eflux_errp", "eflux_errn", "eflux_ul"],
-    "likelihood": ["norm_err", "norm_errn", "norm_errp", "norm_ul"],
+    "likelihood": ["norm_err", "norm_errn", "norm_errp", "norm_ul", "norm_sensitivity"],
 }
 
 VALID_QUANTITIES = [
@@ -113,12 +112,12 @@ class FluxMaps:
     It contains a set of `~gammapy.maps.Map` objects that store the estimated
     flux as a function of energy as well as associated quantities (typically
     errors, upper limits, delta TS and possibly raw quantities such counts,
-    excesses etc). It also contains a reference model to convert the flux
+    excesses etc.). It also contains a reference model to convert the flux
     values in different formats. Usually, this should be the model used to
     produce the flux map.
 
-    The associated map geometry can use a `RegionGeom` to store the equivalent
-    of flux points, or a `WcsGeom`/`HpxGeom` to store an energy dependent flux map.
+    The associated map geometry can use a `~gammapy.maps.RegionGeom` to store the equivalent
+    of flux points, or a `~gammapy.maps.WcsGeom`/`~gammapy.maps.HpxGeom` to store an energy dependent flux map.
 
     The container relies internally on the 'Likelihood' SED type defined in
     :ref:`gadf:flux-points` and offers convenience properties to convert to
@@ -279,12 +278,12 @@ class FluxMaps:
 
     @property
     def n_sigma(self):
-        """n sigma"""
+        """Number of sigma."""
         return self.meta.get("n_sigma", 1)
 
     @property
     def n_sigma_ul(self):
-        """n sigma UL."""
+        """Number of sigma UL."""
         return self.meta.get("n_sigma_ul")
 
     @property
