@@ -27,6 +27,8 @@ __all__ = ["FluxPoints"]
 
 log = logging.getLogger(__name__)
 
+DEFAULT_LABEL_TEMPLATE = "{quantity} [{unit}]"
+
 
 def squash_fluxpoints(flux_point, axis):
     """Squash a `~FluxPoints` object into one point.
@@ -35,6 +37,18 @@ def squash_fluxpoints(flux_point, axis):
     to compute the resultant quantities. Stat profiles
     must be present on the `~FluxPoints` object for
     this method to work.
+
+    Parameters
+    ----------
+    flux_point : `~gammapy.estimators.FluxPoints`
+        Flux points object to squash.
+    axis : `MapAxis` or `TimeMapAxis`
+        Axis along which to squash the flux points.
+
+    Returns
+    -------
+    combined_fp : `~gammapy.estimators.FluxPoints`
+        New flux points object.
     """
     value_scan = flux_point.stat_scan.geom.axes["norm"].center
     stat_scan = np.sum(flux_point.stat_scan.data, axis=0).ravel()
@@ -52,32 +66,41 @@ def squash_fluxpoints(flux_point, axis):
     if axis.name != "energy":
         geom = geom.to_cube([flux_point.geom.axes["energy"]])
 
-    maps["norm"] = Map.from_geom(geom, data=minimizer.x)
+    maps["norm"] = Map.from_geom(geom, data=minimizer.x.reshape(geom.data_shape))
     maps["norm_err"] = Map.from_geom(
         geom, data=np.sqrt(minimizer.hess_inv.todense()).reshape(geom.data_shape)
     )
-    maps["n_dof"] = Map.from_geom(geom, data=flux_point.geom.axes[axis.name].nbin)
+    maps["n_dof"] = Map.from_geom(
+        geom, data=np.reshape(flux_point.geom.axes[axis.name].nbin, geom.data_shape)
+    )
 
     if "norm_ul" in flux_point.available_quantities:
         delta_ts = flux_point.meta.get("n_sigma_ul", 2) ** 2
-        ul = stat_profile_ul_scipy(value_scan, stat_scan, delta_ts=delta_ts)
-        maps["norm_ul"] = Map.from_geom(geom, data=ul.value)
+        try:
+            ul = stat_profile_ul_scipy(value_scan, stat_scan, delta_ts=delta_ts)
+        except (ValueError, RuntimeError):
+            ul = np.nan
+        maps["norm_ul"] = Map.from_geom(geom, data=np.reshape(ul, geom.data_shape))
 
-    maps["stat"] = Map.from_geom(geom, data=f(minimizer.x))
+    maps["stat"] = Map.from_geom(geom, data=f(minimizer.x).reshape(geom.data_shape))
 
     geom_scan = geom.to_cube([MapAxis.from_nodes(value_scan, name="norm")])
     maps["stat_scan"] = Map.from_geom(
         geom=geom_scan, data=stat_scan.reshape(geom_scan.data_shape)
     )
     try:
-        maps["stat_null"] = Map.from_geom(geom, data=np.sum(flux_point.stat_null.data))
+        maps["stat_null"] = Map.from_geom(
+            geom, data=np.reshape(np.sum(flux_point.stat_null.data), geom.data_shape)
+        )
         maps["ts"] = maps["stat_null"] - maps["stat"]
     except AttributeError:
         log.info(
             "Stat null info not present on original FluxPoints object. TS not computed"
         )
 
-    maps["success"] = Map.from_geom(geom=geom, data=minimizer.success, dtype=bool)
+    maps["success"] = Map.from_geom(
+        geom=geom, data=np.reshape(minimizer.success, geom.data_shape), dtype=bool
+    )
 
     combined_fp = FluxPoints.from_maps(
         maps=maps,
@@ -103,13 +126,33 @@ class FluxPoints(FluxMaps):
 
     Parameters
     ----------
-    table : `~astropy.table.Table`
-        Table with flux point data.
+    data : dict of `~gammapy.maps.RegionNDMap`
+        The maps dictionary. Expected entries are the following:
 
-    Attributes
-    ----------
-    table : `~astropy.table.Table`
-        Table with flux point data.
+        * norm : the norm factor.
+        * norm_err : optional, the error on the norm factor.
+        * norm_errn : optional, the negative error on the norm factor.
+        * norm_errp : optional, the positive error on the norm factor.
+        * norm_ul : optional, the upper limit on the norm factor.
+        * norm_scan : optional, the norm values of the test statistic scan.
+        * stat_scan : optional, the test statistic scan values.
+        * ts : optional, the delta test statistic associated with the flux value.
+        * sqrt_ts : optional, the square root of the test statistic, when relevant.
+        * success : optional, a boolean tagging the validity of the estimation.
+        * n_dof : optional, the number of degrees of freedom used in TS computation
+        * alpha : optional, normalisation factor to accounts for differences between the test region and the background
+        * acceptance_off : optional, acceptance from the off region
+        * acceptance_on : optional, acceptance from the on region
+
+    reference_model : `~gammapy.modeling.models.SkyModel`, optional
+        The reference model to use for conversions. If None, a model consisting
+        of a point source with a power law spectrum of index 2 is assumed.
+    meta : dict, optional
+        Dict of metadata.
+    gti : `~gammapy.data.GTI`, optional
+        Maps GTI information.
+    filter_success_nan : boolean, optional
+        Set fitted norm and error to NaN when the fit has not succeeded.
 
     Examples
     --------
@@ -667,11 +710,8 @@ class FluxPoints(FluxMaps):
         flux = scale_plot_flux(flux=flux.to_unit(flux_unit), energy_power=energy_power)
         if "time" in flux.geom.axes_names:
             flux.geom.axes["time"].time_format = time_format
-            ax = flux.plot(ax=ax, **kwargs)
-        else:
-            ax = flux.plot(ax=ax, **kwargs)
-            ax.set_xlabel(f"Energy [{ax.xaxis.units.to_string(UNIT_STRING_FORMAT)}]")
-            ax.set_xscale("log", nonpositive="clip")
+
+        ax = flux.plot(ax=ax, **kwargs)
         self._plot_format_yax(ax=ax, energy_power=energy_power, sed_type=sed_type)
 
         if len(flux.geom.axes) > 1:
@@ -681,14 +721,16 @@ class FluxPoints(FluxMaps):
     @staticmethod
     def _plot_format_yax(ax, energy_power, sed_type):
         if energy_power > 0:
-            ax.set_ylabel(
-                f"e{energy_power} * {sed_type} [{ax.yaxis.units.to_string(UNIT_STRING_FORMAT)}]"
+            ylabel = DEFAULT_LABEL_TEMPLATE.format(
+                quantity=f"e{energy_power} * {sed_type}",
+                unit=ax.yaxis.units.to_string(UNIT_STRING_FORMAT),
             )
         else:
-            ax.set_ylabel(
-                f"{sed_type} [{ax.yaxis.units.to_string(UNIT_STRING_FORMAT)}]"
+            ylabel = DEFAULT_LABEL_TEMPLATE.format(
+                quantity=f"{sed_type}",
+                unit=ax.yaxis.units.to_string(UNIT_STRING_FORMAT),
             )
-
+        ax.set_ylabel(ylabel)
         ax.set_yscale("log", nonpositive="clip")
 
     def plot_ts_profiles(
@@ -795,8 +837,9 @@ class FluxPoints(FluxMaps):
 
         Parameters
         ----------
-        n_sigma_ul : int
-            Number of sigma to use for upper limit computation. Default is 2.
+        n_sigma_ul : float, optional
+            Number of sigma to use for upper limit computation. Must be a positive value.
+            Default is 2.
         **kwargs : dict, optional
             Keyword arguments passed to `~scipy.optimize.brentq`.
 
@@ -808,13 +851,13 @@ class FluxPoints(FluxMaps):
         Examples
         --------
         >>> from gammapy.estimators import FluxPoints
-        >>> filename = '$GAMMAPY_DATA/tests/spectrum/flux_points/binlike.fits'
+        >>> filename = "$GAMMAPY_DATA/estimators/crab_hess_fp/crab_hess_fp.fits"
         >>> flux_points = FluxPoints.read(filename)
-        >>> flux_points_recomputed = flux_points.recompute_ul(n_sigma_ul=3)
-        >>> print(flux_points.meta["n_sigma_ul"], flux_points.flux_ul.data[0])
-        2.0 [[3.95451985e-09]]
-        >>> print(flux_points_recomputed.meta["n_sigma_ul"], flux_points_recomputed.flux_ul.data[0])
-        3 [[6.22245374e-09]]
+        >>> flux_points_recomputed = flux_points.recompute_ul(n_sigma_ul=4)
+        >>> print(f'{flux_points.meta["n_sigma_ul"]}, {float(flux_points.flux_ul.data[1][0]):.2e}')
+        3.0, 3.99e-11
+        >>> print(f'{flux_points_recomputed.meta["n_sigma_ul"]}, {float(flux_points_recomputed.flux_ul.data[1][0]):.2e}')
+        4, 4.25e-11
         """
         if not self.has_stat_profiles:
             raise ValueError(
@@ -828,12 +871,14 @@ class FluxPoints(FluxMaps):
         value_scan = self.stat_scan.geom.axes["norm"].center
         shape_axes = self.stat_scan.geom._shape[slice(3, None)][::-1]
         for idx in np.ndindex(shape_axes):
-            stat_scan = np.abs(
-                self.stat_scan.data[idx].squeeze() - self.stat.data[idx].squeeze()
-            )
-            flux_points.norm_ul.data[idx] = stat_profile_ul_scipy(
-                value_scan, stat_scan, delta_ts=delta_ts, **kwargs
-            )
+            stat_scan = self.stat_scan.data[idx].squeeze()
+            try:
+                ul = stat_profile_ul_scipy(
+                    value_scan, stat_scan, delta_ts=delta_ts, **kwargs
+                )
+            except (ValueError, RuntimeError):
+                ul = np.nan
+            flux_points.norm_ul.data[idx] = ul
         flux_points.meta["n_sigma_ul"] = n_sigma_ul
         return flux_points
 
