@@ -97,18 +97,7 @@ def find_peaks(image, threshold, min_distance=1):
     >>> maps = estimator.run(dataset)
     >>> # Find the peaks which are above 5 sigma
     >>> sources = find_peaks(maps["sqrt_ts"], threshold=5, min_distance="0.25 deg")
-    >>> print(sources)
-    value   x   y      ra       dec
-                      deg       deg
-    ------ --- --- --------- ---------
-    32.191 161 118 266.41924 -28.98772
-      18.7 125 124 266.80571 -28.14079
-    9.4498 257 122 264.86178 -30.97529
-    9.3784 204 103 266.14201 -30.10041
-    5.3493 282 150 263.78083 -31.12704
     """
-    # Input validation
-
     if not isinstance(image, WcsNDMap):
         raise TypeError("find_peaks only supports WcsNDMap")
 
@@ -197,14 +186,7 @@ def find_peaks_in_flux_map(maps, threshold, min_distance=1):
     >>> maps = estimator.run(dataset)
     >>> # Find the peaks which are above 5 sigma
     >>> sources = find_peaks_in_flux_map(maps, threshold=5, min_distance=0.1*u.deg)
-    >>> print(sources[:4])
-    x   y      ra       dec      npred   npred_excess   counts     ts    sqrt_ts   norm  norm_err     flux      flux_err
-               deg       deg                                                                       1 / (s cm2) 1 / (s cm2)
-    --- --- --------- --------- --------- ------------ --------- -------- ------- ------- -------- ----------- -----------
-    158 135 266.05019 -28.70181 192.00000     61.33788 192.00000 25.11839 5.01183 0.28551  0.06450   2.827e-12   6.385e-13
-     92 133 267.07022 -27.31834 137.00000     51.99467 137.00000 26.78181 5.17511 0.37058  0.08342   3.669e-12   8.259e-13
-    176 134 265.80492 -29.09805 195.00000     65.15990 195.00000 28.29158 5.31898 0.30561  0.06549   3.025e-12   6.484e-13
-    282 150 263.78083 -31.12704  84.00000     39.99004  84.00000 28.61526 5.34932 0.55027  0.12611   5.448e-12   1.249e-12
+
     """
     quantity_for_peaks = maps["sqrt_ts"]
 
@@ -279,6 +261,32 @@ def estimate_exposure_reco_energy(dataset, spectral_model=None, normalize=True):
     -------
     exposure : `~gammapy.maps.Map`
         Exposure map in reconstructed energy.
+
+    Examples
+    --------
+    .. testcode::
+
+        from gammapy.datasets import MapDataset
+        from gammapy.estimators.utils import estimate_exposure_reco_energy
+        from gammapy.modeling.models import PowerLawSpectralModel
+        dataset = MapDataset.read("$GAMMAPY_DATA/cta-1dc-gc/cta-1dc-gc.fits.gz")
+        spectral_model = PowerLawSpectralModel()
+        reco_exposure = estimate_exposure_reco_energy(
+            dataset,
+            spectral_model=spectral_model,
+        )
+        print(reco_exposure)
+
+    .. testoutput::
+
+        WcsNDMap
+
+        geom  : WcsGeom
+        axes  : ['lon', 'lat', 'energy']
+        shape : (320, 240, 10)
+        ndim  : 3
+        unit  : cm2 s
+        dtype : float64
     """
     if spectral_model is None:
         spectral_model = PowerLawSpectralModel()
@@ -405,13 +413,26 @@ def compute_lightcurve_fvar(lightcurve, flux_quantity="flux"):
     ----------
     lightcurve : `~gammapy.estimators.FluxPoints`
         The lightcurve object.
-    flux_quantity : str
+    flux_quantity : str, optional
         Flux quantity to use for calculation. Should be 'dnde', 'flux', 'e2dnde' or 'eflux'. Default is 'flux'.
 
     Returns
     -------
     fvar : `~astropy.table.Table`
         Table of fractional excess variance and associated error for each energy bin of the lightcurve.
+
+    Examples
+    --------
+    .. testcode::
+
+        from gammapy.estimators import FluxPoints
+        from gammapy.estimators.utils import compute_lightcurve_fvar
+
+        lightcurve = FluxPoints.read(
+            "$GAMMAPY_DATA/estimators/pks2155_hess_lc/pks2155_hess_lc.fits",
+            format="lightcurve",
+        )
+        fvar = compute_lightcurve_fvar(lightcurve)
     """
     flux = getattr(lightcurve, flux_quantity)
     flux_err = getattr(lightcurve, flux_quantity + "_err")
@@ -442,13 +463,26 @@ def compute_lightcurve_fpp(lightcurve, flux_quantity="flux"):
     ----------
     lightcurve : `~gammapy.estimators.FluxPoints`
         The lightcurve object.
-    flux_quantity : str
+    flux_quantity : str, optional
         Flux quantity to use for calculation. Should be 'dnde', 'flux', 'e2dnde' or 'eflux'. Default is 'flux'.
 
     Returns
     -------
     table : `~astropy.table.Table`
         Table of point-to-point excess variance and associated error for each energy bin of the lightcurve.
+
+    Examples
+    --------
+    .. testcode::
+
+        from gammapy.estimators import FluxPoints
+        from gammapy.estimators.utils import compute_lightcurve_fpp
+
+        lightcurve = FluxPoints.read(
+            "$GAMMAPY_DATA/estimators/pks2155_hess_lc/pks2155_hess_lc.fits",
+            format="lightcurve",
+        )
+        fpp = compute_lightcurve_fpp(lightcurve)
     """
     flux = getattr(lightcurve, flux_quantity)
     flux_err = getattr(lightcurve, flux_quantity + "_err")
@@ -487,9 +521,7 @@ def compute_lightcurve_doublingtime(lightcurve, flux_quantity="flux"):
     ----------
     lightcurve : `~gammapy.estimators.FluxPoints`
         The lightcurve object.
-    axis_name : str
-        Name of the axis over which to compute the flux doubling.
-    flux_quantity : str
+    flux_quantity : str, optional
         Flux quantity to use for calculation. Should be 'dnde', 'flux', 'e2dnde' or 'eflux'.
         Default is 'flux'.
 
@@ -499,12 +531,23 @@ def compute_lightcurve_doublingtime(lightcurve, flux_quantity="flux"):
         Table of flux doubling/halving and associated error for each energy bin of the lightcurve
         with axis coordinates at which they were found.
 
+    Examples
+    --------
+    .. testcode::
+
+        from gammapy.estimators import FluxPoints
+        from gammapy.estimators.utils import compute_lightcurve_doublingtime
+
+        lightcurve = FluxPoints.read(
+            "$GAMMAPY_DATA/estimators/pks2155_hess_lc/pks2155_hess_lc.fits",
+            format="lightcurve",
+        )
+        doublingtime = compute_lightcurve_doublingtime(lightcurve)
 
     References
     ----------
-    .. [Brown2013] "Locating the γ-ray emission region
-       of the flat spectrum radio quasar PKS 1510−089", Brown et al. (2013)
-       https://academic.oup.com/mnras/article/431/1/824/1054498
+    `Brown et al. (2013), "Locating the γ-ray emission region of the flat spectrum radio quasar PKS 1510−089"
+    <https://ui.adsabs.harvard.edu/abs/2013MNRAS.431..824B/abstract>`_
     """
     flux = getattr(lightcurve, flux_quantity)
     flux_err = getattr(lightcurve, flux_quantity + "_err")
@@ -560,7 +603,7 @@ def compute_lightcurve_discrete_correlation(
     lightcurve2 : `~gammapy.estimators.FluxPoints`, optional
         The second lightcurve object. If not provided, the autocorrelation for the first lightcurve will be computed.
         Default is None.
-    flux_quantity : str
+    flux_quantity : str, optional
         Flux quantity to use for calculation. Should be 'dnde', 'flux', 'e2dnde' or 'eflux'.
         The choice does not affect the computation. Default is 'flux'.
     tau : `~astropy.units.Quantity`, optional
@@ -576,11 +619,27 @@ def compute_lightcurve_discrete_correlation(
                 * "discrete_correlation" : discrete correlation function values
                 * "discrete_correlation_err" : associated error
 
+    Examples
+    --------
+    .. testcode::
+
+        from gammapy.estimators import FluxPoints
+        from gammapy.estimators.utils import compute_lightcurve_discrete_correlation
+        import astropy.units as u
+
+        lightcurve = FluxPoints.read(
+            "$GAMMAPY_DATA/estimators/pks2155_hess_lc/pks2155_hess_lc.fits",
+            format="lightcurve",
+        )
+        discrete_correlation = compute_lightcurve_discrete_correlation(
+            lightcurve,
+            tau=3*u.d,
+        )
+
     References
     ----------
-    .. [Edelson1988] "THE DISCRETE CORRELATION FUNCTION: A NEW METHOD FOR ANALYZING
-       UNEVENLY SAMPLED VARIABILITY DATA", Edelson et al. (1988)
-       https://ui.adsabs.harvard.edu/abs/1988ApJ...333..646E/abstract
+    `Edelson et al. (1988), "THE DISCRETE CORRELATION FUNCTION: A NEW METHOD FOR ANALYZING
+    UNEVENLY SAMPLED VARIABILITY DATA" <https://ui.adsabs.harvard.edu/abs/1988ApJ...333..646E/abstract>`_
     """
     flux1 = getattr(lightcurve1, flux_quantity)
     flux_err1 = getattr(lightcurve1, flux_quantity + "_err")
@@ -783,7 +842,8 @@ def get_rebinned_axis(fluxpoint, axis_name="energy", method=None, **kwargs):
 
 
 def combine_significance_maps(maps):
-    """Computes excess and significance for a set of datasets.
+    """Compute excess and significance for a set of datasets.
+
     The significance computation assumes that the model contains
     one degree of freedom per valid energy bin in each dataset.
     The method implemented here is valid under the assumption
@@ -809,12 +869,11 @@ def combine_significance_maps(maps):
                 * "npred_excess" : summed excess map.
                 * "estimator_results" : dictionary containing the flux maps computed for each dataset.
 
-    See also
+    See Also
     --------
     get_combined_significance_maps : same method but computing the significance maps from estimators and datasets.
 
     """
-
     geom = maps[0].ts.geom.to_image()
     ts_sum = Map.from_geom(geom)
     ts_sum_sign = Map.from_geom(geom)
@@ -834,6 +893,7 @@ def combine_significance_maps(maps):
     return dict(
         significance=significance,
         df=df,
+        ts=ts_sum,
         npred_excess=npred_excess_sum,
         estimator_results=maps,
     )
@@ -848,15 +908,11 @@ def get_combined_significance_maps(estimator, datasets):
     that the TS in each independent bin follows a Chi2 distribution,
     then the sum of the TS also follows a Chi2 distribution (with the sum of degree of freedom).
 
-    See, Zhen (2014): https://www.sciencedirect.com/science/article/abs/pii/S0167947313003204,
-    Lancaster (1961): https://onlinelibrary.wiley.com/doi/10.1111/j.1467-842X.1961.tb00058.x
-
-
     Parameters
     ----------
     estimator : `~gammapy.estimators.ExcessMapEstimator` or `~gammapy.estimators.TSMapEstimator`
         Excess Map Estimator or TS Map Estimator
-    dataset : `~gammapy.datasets.Datasets`
+    datasets : `~gammapy.datasets.Datasets`
         Datasets containing only `~gammapy.datasets.MapDataset`.
 
     Returns
@@ -869,10 +925,26 @@ def get_combined_significance_maps(estimator, datasets):
                 * "npred_excess" : summed excess map.
                 * "estimator_results" : dictionary containing the flux maps computed for each dataset.
 
-    See also
+    Examples
+    --------
+    >>> from gammapy.datasets import Datasets
+    >>> from gammapy.estimators import ExcessMapEstimator
+    >>> from gammapy.estimators.utils import get_combined_significance_maps
+    >>> datasets = Datasets.read("$GAMMAPY_DATA/hawc/DL4/HAWC_pass4_public_Crab.yaml")
+    >>> estimator = ExcessMapEstimator(correlation_radius="0.2 deg")
+    >>> combined = get_combined_significance_maps(estimator, datasets)
+
+    References
+    ----------
+    * `Chen & Nadarajah (2014), "On the optimally weighted z-test for combining probabilities from independent
+      studies" <https://www.sciencedirect.com/science/article/abs/pii/S0167947313003204>`_
+    * `Lancaster (1961), "The Combination of Probabilities: an Application of Orthonormal Functions"
+      <https://onlinelibrary.wiley.com/doi/10.1111/j.1467-842X.1961.tb00058.x>`_
+
+
+    See Also
     --------
     combine_significance_maps : same method but using directly the significance maps from estimators
-
     """
     from .map.excess import ExcessMapEstimator
     from .map.ts import TSMapEstimator
@@ -931,7 +1003,7 @@ def combine_flux_maps(
         Joint flux map.
 
 
-    See also
+    See Also
     --------
     get_combined_flux_maps : same method but using directly the flux maps from estimators
 
@@ -1038,7 +1110,7 @@ def get_combined_flux_maps(
     ----------
     estimator : `~gammapy.estimators.ExcessMapEstimator` or `~gammapy.estimators.TSMapEstimator`
         Excess Map Estimator or TS Map Estimator
-    dataset : `~gammapy.datasets.Datasets` or list of `~gammapy.datasets.MapDataset`
+    datasets : `~gammapy.datasets.Datasets` or list of `~gammapy.datasets.MapDataset`
         Datasets containing only `~gammapy.datasets.MapDataset`.
     method : str
         * gaussian_errors :
@@ -1050,7 +1122,7 @@ def get_combined_flux_maps(
             Use available quantities among dnde, dnde_err, dnde_errp, dnde_errn, dnde_ul, and ts.
         * profile :
             Sum the likelihood profile maps.
-            The flux maps must contains the `stat_scan` maps.
+            The flux maps must contain the `stat_scan` maps.
 
         Default is "gaussian_errors" which is the faster but least accurate solution,
         "distrib"  will be more accurate if dnde_errp and dnde_errn are available,
@@ -1058,7 +1130,7 @@ def get_combined_flux_maps(
 
     reference_model : `~gammapy.modeling.models.SkyModel`, optional
         Reference model to use for conversions.
-        Default is None and is will use the reference_model of the first FluxMaps in the list.
+        Default is None and is will use the reference_model of the first `~gammapy.estimators.FluxMaps` in the list.
     dnde_scan_axis : `~gammapy.maps.MapAxis`, optional
         Map axis providing the dnde values used to compute the profile.
         If None, it will be derived from the first FluxMaps in the list. Default is None.
@@ -1072,7 +1144,16 @@ def get_combined_flux_maps(
                 * "flux_maps" : `gammapy.estimators.FluxMaps`
                 * "estimator_results" : dictionary containing the flux maps computed for each dataset.
 
-    See also
+    Examples
+    --------
+    >>> from gammapy.datasets import Datasets
+    >>> from gammapy.estimators import TSMapEstimator
+    >>> from gammapy.estimators.utils import get_combined_flux_maps
+    >>> datasets = Datasets.read("$GAMMAPY_DATA/hawc/DL4/HAWC_pass4_public_Crab.yaml")
+    >>> estimator = TSMapEstimator()
+    >>> combined = get_combined_flux_maps(estimator, datasets)
+
+    See Also
     --------
     combine_flux_maps : same method but using directly the flux maps from estimators
 
@@ -1248,10 +1329,10 @@ def get_flux_map_from_profile(
     ----------
     flux_maps : `~gammapy.estimators.FluxMaps` or dict of `~gammapy.maps.WcsNDMap`
         Flux map or dict containing  a `stat_scan` entry
-    n_sigma : int
-        Number of sigma for flux error. Default is 1.
-    n_sigma_ul : int
-        Number of sigma for flux upper limits. Default is 2.
+    n_sigma : float, optional
+        Number of sigma for flux error. Must be a positive value. Default is 1.
+    n_sigma_ul : float, optional
+        Number of sigma for flux upper limits. Must be a positive value. Default is 2.
     reference_model : `~gammapy.modeling.models.SkyModel`, optional
         The reference model to use for conversions. If None, a model consisting
         of a point source with a power law spectrum of index 2 is assumed.
@@ -1267,7 +1348,6 @@ def get_flux_map_from_profile(
     -------
     flux_maps : `~gammapy.estimators.FluxMaps`
         Flux map.
-
     """
     if isinstance(flux_map, dict):
         output_maps = flux_map
@@ -1349,6 +1429,7 @@ def _get_default_norm(
     scan_min=0.2,
     scan_max=5,
     scan_n_values=11,
+    scan_n_sigma=2,
     scan_values=None,
     interp="lin",
 ):
@@ -1363,6 +1444,7 @@ def _get_default_norm(
             scan_min=scan_min,
             scan_max=scan_max,
             scan_n_values=scan_n_values,
+            scan_n_sigma=scan_n_sigma,
             scan_values=scan_values,
         )
         if isinstance(norm, dict):
@@ -1398,3 +1480,14 @@ def _get_norm_scan_values(norm, result):
         rand_norms = 20 * np.random.rand(109 - len(sparse_norms)) - 10
         sparse_norms = np.concatenate((sparse_norms, rand_norms))
     return np.sort(sparse_norms)
+
+
+def apply_threshold_sensitivity(
+    background, excess_counts, gamma_min=10, bkg_syst_fraction=0.05
+):
+    """Apply sensitivity  threshold in case it is limited by statistic or background."""
+    is_gamma_limited = excess_counts < gamma_min
+    excess_counts[is_gamma_limited] = gamma_min
+    bkg_syst_limited = excess_counts < bkg_syst_fraction * background
+    excess_counts[bkg_syst_limited] = bkg_syst_fraction * background[bkg_syst_limited]
+    return excess_counts
