@@ -1,13 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Instrument response functions (IRFs).
-"""
+"""Instrument response functions (IRFs)."""
 from gammapy.utils.registry import Registry
-from .background import Background2D, Background3D
-from .core import FoVAlignment, IRFMap
+from .background import Background2D, Background3D, BackgroundIRF
+from .core import IRF, FoVAlignment, IRFMap
 from .edisp import EDispKernel, EDispKernelMap, EDispMap, EnergyDispersion2D
 from .effective_area import EffectiveAreaTable2D
-from .io import load_cta_irfs, load_irf_dict_from_file
+from .io import load_irf_dict_from_file
 from .psf import (
     PSF3D,
     EnergyDependentMultiGaussPSF,
@@ -22,6 +20,7 @@ from .rad_max import RadMax2D
 __all__ = [
     "Background2D",
     "Background3D",
+    "BackgroundIRF",
     "EDispKernel",
     "EDispKernelMap",
     "EDispMap",
@@ -31,7 +30,7 @@ __all__ = [
     "FoVAlignment",
     "IRF_REGISTRY",
     "IRFMap",
-    "load_cta_irfs",
+    "IRF",
     "load_irf_dict_from_file",
     "ParametricPSF",
     "PSF3D",
