@@ -9,10 +9,10 @@ from gammapy.maps.axes import UNIT_STRING_FORMAT
 from gammapy.modeling.models import PowerLawSpectralModel
 from gammapy.utils.gauss import Gauss2DPDF
 from gammapy.utils.random import InverseCDFSampler, get_random_state
+from gammapy.utils.units import energy_unit_format
 from ..core import IRFMap
 from .core import PSF
 from .kernel import PSFKernel
-from gammapy.utils.deprecation import deprecated_renamed_argument
 
 __all__ = ["PSFMap", "RecoPSFMap"]
 
@@ -24,9 +24,7 @@ def _psf_upsampling_factor(psf, geom, position, energy=None, precision_factor=12
     """Minimal factor between the bin half-width of the geom and the median R68% containment radius."""
     if energy is None:
         energy = geom.axes[psf.energy_name].center
-    psf_r68s = psf.containment_radius(
-        0.68, geom.axes[psf.energy_name].center, position=position
-    )
+    psf_r68s = psf.containment_radius(0.68, energy, position=position)
     factors = []
     for psf_r68 in psf_r68s:
         base_factor = (2 * psf_r68 / geom.pixel_scales.max()).to_value("")
@@ -122,7 +120,7 @@ class PSFMap(IRFMap):
 
         Parameters
         ----------
-        geom : `Geom`
+        geom : `~gammapy.maps.Geom`
             PSF map geometry.
 
         Returns
@@ -276,14 +274,13 @@ class PSFMap(IRFMap):
             Default is 0.999.
         precision_factor : int, optional
             Factor between the bin half-width of the geom and the median R68% containment radius.
-            Used only for the oversampling method. Default is 10.
+            Used only for the oversampling method. Default is 12.
 
         Returns
         -------
         kernel : `~gammapy.irf.PSFKernel` or list of `PSFKernel`
             The resulting kernel.
         """
-
         if geom.is_region or geom.is_hpx:
             geom = geom.to_wcs_geom()
 
@@ -306,7 +303,9 @@ class PSFMap(IRFMap):
             radii[radii > max_radius] = max_radius
 
         n_radii = len(radii)
-        factor = _psf_upsampling_factor(self, geom, position, precision_factor)
+        factor = _psf_upsampling_factor(
+            self, geom, position, energy=None, precision_factor=precision_factor
+        )
         geom = geom.to_odd_npix(max_radius=max_radius)
         kernel_map = Map.from_geom(geom=geom)
         for im, ind in zip(kernel_map.iter_by_image(keepdims=True), range(n_radii)):
@@ -412,7 +411,7 @@ class PSFMap(IRFMap):
             Offset angle wrt source position axis.
         sigma : `~astropy.coordinates.Angle`
             Gaussian width.
-        geom : `Geom`
+        geom : `~gammapy.maps.Geom`
             Image geometry. By default, an all-sky geometry is created.
 
         Returns
@@ -448,7 +447,6 @@ class PSFMap(IRFMap):
         )
         return cls(psf_map=psf_map, exposure_map=exposure_map)
 
-    @deprecated_renamed_argument("spectrum", "spectral_model", "v1.3")
     def to_image(self, spectral_model=None, keepdims=True):
         """Reduce to a 2D map after weighing with the associated exposure and a spectrum.
 
@@ -534,8 +532,9 @@ class PSFMap(IRFMap):
         ----------
         ax : `~matplotlib.pyplot.Axes`, optional
             Matplotlib axes. Default is None.
-        energy : `~astropy.units.Quantity`
+        energy_true : `~astropy.units.Quantity`, optional
             Energies where to plot the PSF.
+            Default is [0.1, 1, 10] TeV.
         **kwargs : dict
             Keyword arguments pass to `~matplotlib.pyplot.plot`.
 
@@ -557,7 +556,7 @@ class PSFMap(IRFMap):
                     "rad": rad,
                 }
             )
-            label = f"{value:.0f}"
+            label = f"{energy_unit_format(value)}"
             psf_value *= self.psf_map.unit
             with quantity_support():
                 ax.plot(rad, psf_value, label=label, **kwargs)
@@ -575,10 +574,18 @@ class PSFMap(IRFMap):
     def peek(self, figsize=(12, 10)):
         """Quick-look summary plots.
 
+        This method creates a figure with four subplots:
+
+        * Containment radius at center of map plot : Containment radius as a function of energy for
+          containment fractions of 65% and 95%.
+        * PSF at center of map plot : PSF vs radius.
+        * Exposure 2D map : exposure summed over true energy
+        * Containment radius map : 2D sky map of the 68% containment radius at 1 TeV
+
         Parameters
         ----------
-        figsize : tuple
-            Size of figure.
+        figsize : tuple, optional
+            Size of figure. Default is (12, 10).
         """
         fig, axes = plt.subplots(
             ncols=2,
@@ -646,7 +653,7 @@ class RecoPSFMap(PSFMap):
             Offset angle wrt source position axis.
         sigma : `~astropy.coordinates.Angle`
             Gaussian width.
-        geom : `Geom`
+        geom : `~gammapy.maps.Geom`
             Image geometry. By default, an all-sky geometry is created.
 
         Returns
@@ -721,8 +728,9 @@ class RecoPSFMap(PSFMap):
         ----------
         ax : `~matplotlib.pyplot.Axes`, optional
             Matplotlib axes. Default is None.
-        energy : `~astropy.units.Quantity`
+        energy : `~astropy.units.Quantity`, optional
             Energies where to plot the PSF.
+            Default is [0.1, 1, 10] TeV.
         **kwargs : dict
             Keyword arguments pass to `~matplotlib.pyplot.plot`.
 
