@@ -22,6 +22,7 @@ from gammapy.irf import Background2D, EDispKernelMap, EDispMap, PSFMap
 from gammapy.makers import FoVBackgroundMaker, MapDatasetMaker, SafeMaskMaker
 from gammapy.maps import HpxGeom, Map, MapAxis, WcsGeom
 from gammapy.utils.testing import requires_data, requires_dependency
+from gammapy.utils.scripts import make_path
 
 
 @pytest.fixture(scope="session")
@@ -367,6 +368,8 @@ def test_interpolate_map_dataset():
         geom=geom_target, energy_axis_true=energy_true, rad_axis=rad_axis, name="test"
     )
     dataset = maker.run(dataset, obs)
+    assert dataset.psf.exposure_map and np.all(dataset.psf.exposure_map.data == 1.0)
+    assert dataset.edisp.exposure_map and np.all(dataset.edisp.exposure_map.data == 0.0)
 
     # test counts
     assert dataset.counts.data.sum() == nr_ev
@@ -408,6 +411,10 @@ def test_interpolate_map_dataset():
     ).data
     assert_allclose(psfkernel_preinterp, psfkernel_postinterp, atol=1e-4)
 
+    # test running maker with dataset
+    maker = MapDatasetMaker(selection=["exposure", "edisp", "psf"])
+    dataset = maker.run(dataset, dataset)
+
 
 @requires_data()
 @pytest.mark.xfail
@@ -483,7 +490,6 @@ def test_dataset_hawc():
     results["NN"] = [6.57154247837e16, 62, 0.76743538]
 
     for which in ["GP", "NN"]:
-
         # paths and file names
         data_path = "$GAMMAPY_DATA/hawc/crab_events_pass4/"
         hdu_filename = "hdu-index-table-" + which + "-Crab.fits.gz"
@@ -561,3 +567,81 @@ def test_meta_data_creation(observations):
     stacked_meta = MapDatasetMetaData._from_meta_table(dataset0.meta_table)
     assert stacked_meta.obs_info[0].obs_id == 110380
     assert stacked_meta.obs_info[1].obs_id == 111140
+
+
+@requires_data()
+def test_map_dataset_maker_swgo():
+    times = Time([59249.83472222222, 62802.21805555555], format="mjd", scale="tt")
+    tref = Time(51544.00074287037, format="mjd", scale="tt")
+
+    gti = GTI.from_time_intervals([times], reference_time=tref)
+
+    path = make_path("$GAMMAPY_DATA/tests/format/swgo/")
+
+    datastore = DataStore.from_dir(path, "hdu-index.fits.gz", "obs-index.fits.gz")
+
+    observation_groups = datastore.get_observation_groups("EVENT_TYPE")
+
+    observation_groups_redu = datastore.get_observations(obs_id=[3, 2])
+    assert observation_groups_redu.ids == ["3", "2"]
+    observation_groups_redu = datastore.get_observation_groups(
+        "EVENT_TYPE", obs_id=[3, 2]
+    )
+
+    event_type = datastore.obs_table["EVENT_TYPE"][3]
+    assert observation_groups_redu["EVENT_TYPE_" + event_type].ids[0] == "3"
+
+    event_type = datastore.obs_table["EVENT_TYPE"][2]
+    assert observation_groups_redu["EVENT_TYPE_" + event_type].ids[0] == "2"
+
+    selection_mask = np.array([1, 0, 1, 0, 1, 1], dtype=bool)
+    observation_groups_redu = datastore.get_observation_groups(
+        "EVENT_TYPE", obs_id=[2, 3], selection=selection_mask
+    )
+    assert observation_groups_redu["EVENT_TYPE_" + event_type].ids[0] == "2"
+    assert len(observation_groups_redu) == 1
+
+    event_type = datastore.obs_table["EVENT_TYPE"][0]
+    selection_mask = datastore.obs_table["EVENT_TYPE"] == event_type
+    observations_redu = datastore.get_observations(
+        obs_id=datastore.obs_ids, selection=selection_mask
+    )
+
+    assert observations_redu.ids == observation_groups["EVENT_TYPE_" + event_type].ids
+
+    obs = observations_redu[0]
+    obs.gti = gti
+
+    with pytest.raises(ValueError):
+        obs.gti = gti
+
+    energy_axis = MapAxis.from_energy_bounds(
+        0.3 * u.TeV, 300 * u.TeV, 10, per_decade=True
+    )
+    energy_true_axis = MapAxis.from_energy_bounds(
+        0.1 * u.TeV, 1000 * u.TeV, 10, per_decade=True, name="energy_true"
+    )
+
+    geom = obs.aeff.geom.to_image().to_cube([energy_axis])
+
+    rad_axis = obs.psf.psf_map.geom.axes["rad"]
+    geom_psf = obs.psf.psf_map.geom.to_image().to_cube([rad_axis, energy_true_axis])
+    geom_edisp = obs.edisp.edisp_map.geom.to_image().to_cube(
+        [energy_axis, energy_true_axis]
+    )
+    geom_exposure = geom.to_image().to_cube([energy_true_axis])
+
+    dataset_empty = MapDataset.from_geoms(
+        geom,
+        geom_exposure=geom_exposure,
+        geom_psf=geom_psf,
+        geom_edisp=geom_edisp,
+    )
+
+    maker = MapDatasetMaker(selection=["background", "exposure", "edisp", "psf"])
+    dataset = maker.run(dataset_empty, obs)
+
+    assert dataset.exposure.data.shape == (40, 180, 1)
+    assert dataset.psf.psf_map.data.shape == (40, 500, 180, 1)
+    assert dataset.edisp.edisp_map.data.shape == (40, 30, 180, 1)
+    assert dataset.background.data.shape == (30, 180, 1)
