@@ -3,11 +3,18 @@ import pytest
 import numpy as np
 from numpy.testing import assert_allclose
 from astropy import units as u
-from astropy.coordinates import EarthLocation, SkyCoord
+from astropy.coordinates import SkyCoord
 from astropy.table import Table
 from astropy.time import Time
 from regions import PointSkyRegion
-from gammapy.data import GTI, DataStore, EventList, FixedPointingInfo, Observation
+from gammapy.data import (
+    GTI,
+    DataStore,
+    EventList,
+    FixedPointingInfo,
+    Observation,
+    observatory_locations,
+)
 from gammapy.irf import (
     Background2D,
     Background3D,
@@ -117,17 +124,9 @@ def fixed_pointing_info():
 def fixed_pointing_info_aligned():
     # Create Fixed Pointing Info aligned between sky and horizon coordinates
     # (removes rotation in FoV and results in predictable solid angles)
-    time_start = Time("2000-09-21 11:55:00")
-    time_stop = Time("2000-09-12 12:05:00")
-    location = EarthLocation(lat=90 * u.deg, lon=0 * u.deg)
     fixed_icrs = SkyCoord(0 * u.deg, 0 * u.deg, frame="icrs")
 
-    return FixedPointingInfo(
-        fixed_icrs=fixed_icrs,
-        location=location,
-        time_start=time_start,
-        time_stop=time_stop,
-    )
+    return FixedPointingInfo(fixed_icrs=fixed_icrs)
 
 
 @pytest.fixture(scope="session")
@@ -164,7 +163,6 @@ def bkg_3d_custom(symmetry="constant", fov_align="RADEC"):
     energy_axis = MapAxis.from_energy_edges([0.1, 10, 1000] * u.TeV)
     fov_lon_axis = MapAxis.from_edges([-3, -1, 1, 3] * u.deg, name="fov_lon")
     fov_lat_axis = MapAxis.from_edges([-3, -1, 1, 3] * u.deg, name="fov_lat")
-
     return Background3D(
         axes=[energy_axis, fov_lon_axis, fov_lat_axis],
         data=data,
@@ -190,6 +188,8 @@ def test_map_background_2d(bkg_2d, fixed_pointing_info):
         ontime="42 s",
         bkg=bkg_2d,
         geom=geom,
+        time_start=obstime,
+        fov_rotation_step=1.0 * u.deg,
     )
 
     assert_allclose(bkg.data[:, 1, 1], [1.869025, 0.186903], rtol=1e-5)
@@ -200,7 +200,8 @@ def test_map_background_2d(bkg_2d, fixed_pointing_info):
         ontime="42 s",
         bkg=bkg_2d,
         geom=geom,
-        obstime=obstime,
+        time_start=obstime,
+        fov_rotation_step=1.0 * u.deg,
     )
     assert_allclose(bkg.data, bkg_fpi.data, rtol=1e-5)
 
@@ -213,7 +214,8 @@ def make_map_background_irf_with_symmetry(fpi, symmetry="constant"):
         ontime="42 s",
         bkg=bkg_3d_custom(symmetry),
         geom=WcsGeom.create(npix=(3, 3), binsz=4, axes=[axis], skydir=fpi.fixed_icrs),
-        obstime=obstime,
+        time_start=obstime,
+        fov_rotation_step=1.0 * u.deg,
     )
 
 
@@ -262,8 +264,9 @@ def test_make_map_background_irf(bkg_3d, pars, fixed_pointing_info):
             ebounds=pars["ebounds"],
             skydir=fixed_pointing_info.fixed_icrs,
         ),
+        time_start=Time("2020-01-01T20:00"),
+        fov_rotation_step=1.0 * u.deg,
         oversampling=10,
-        obstime=Time("2020-01-01T20:00"),
     )
 
     assert m.data.shape == pars["shape"]
@@ -322,9 +325,103 @@ def test_make_map_background_irf_skycoord(fixed_pointing_info_aligned):
             ontime="42 s",
             bkg=bkg_3d_custom("asymmetric", "ALTAZ"),
             geom=WcsGeom.create(npix=(3, 3), binsz=4, axes=[axis], skydir=position),
+            time_start=Time("2020-01-01T20:00:00"),
+            fov_rotation_step=1.0 * u.deg,
         )
 
 
+@requires_data()
+def test_make_map_background_irf_altaz_align(fixed_pointing_info):
+    def _get_geom(pnt_info, time):
+        axis = MapAxis.from_edges([0.1, 1, 10], name="energy", unit="TeV", interp="log")
+
+        return WcsGeom.create(
+            npix=(10, 10),
+            binsz=0.1,
+            axes=[axis],
+            skydir=pnt_info.get_icrs(time),
+        )
+
+    obstime = Time("2020-01-01T20:00:00")
+    location = observatory_locations["ctao_south"]
+
+    map_long_altaz = make_map_background_irf(
+        pointing=fixed_pointing_info,
+        ontime="42000 s",
+        bkg=bkg_3d_custom("asymmetric", "ALTAZ"),
+        geom=_get_geom(fixed_pointing_info, obstime),
+        time_start=obstime,
+        fov_rotation_step=20.0 * u.deg,
+        location=location,
+    )
+
+    map_short_altaz = make_map_background_irf(
+        pointing=fixed_pointing_info,
+        ontime="42 s",
+        bkg=bkg_3d_custom("asymmetric", "ALTAZ"),
+        geom=_get_geom(fixed_pointing_info, obstime),
+        time_start=obstime + "20979 s",
+        fov_rotation_step=20.0 * u.deg,
+        location=location,
+    )
+    map_long_radec = make_map_background_irf(
+        pointing=fixed_pointing_info,
+        ontime="42000 s",
+        bkg=bkg_3d_custom("asymmetric", "RADEC"),
+        geom=_get_geom(fixed_pointing_info, obstime),
+        time_start=obstime,
+        fov_rotation_step=20.0 * u.deg,
+        location=location,
+    )
+    map_short_altaz_norotation = make_map_background_irf(
+        pointing=fixed_pointing_info,
+        ontime="42 s",
+        bkg=bkg_3d_custom("asymmetric", "ALTAZ"),
+        geom=_get_geom(fixed_pointing_info, obstime),
+        time_start=obstime - 21 * u.s,
+        fov_rotation_step=360.0 * u.deg,
+        location=location,
+    )
+    map_altaz_long_norotation = make_map_background_irf(
+        pointing=fixed_pointing_info,
+        ontime="4200 s",
+        bkg=bkg_3d_custom("asymmetric", "ALTAZ"),
+        geom=_get_geom(fixed_pointing_info, obstime),
+        time_start=obstime - 2100 * u.s,
+        fov_rotation_step=360.0 * u.deg,
+        location=location,
+    )
+    # Check that background normalisations are consistent
+    assert_allclose(np.sum(map_long_altaz.data), np.sum(map_long_radec.data), rtol=1e-2)
+    assert np.isclose(
+        np.sum(map_long_altaz.data), 1000 * np.sum(map_short_altaz.data), rtol=1e-2
+    )
+    # Check that results differ when considering short and long observations with
+    # AltAz aligned IRFs
+    assert_allclose(
+        map_long_altaz.data[0, 0, :4], [252123, 250654, 249086, 247564.0], rtol=1e-2
+    )
+    #    [252123, 250654, 249086, 247564.]
+    assert_allclose(
+        map_short_altaz.data[0, 0, :4],
+        [260.9476, 258.2620, 255.6040, 252.973375],
+        rtol=1e-5,
+    )
+
+    # Check that results differ when considering RaDec or AltAz aligned IRFs
+    assert_allclose(
+        map_long_radec.data[0, 0, :4], [197029, 197029, 197029, 197029.0], rtol=1e-5
+    )
+
+    # Check that results are independent of the observation duration with AltAz
+    # aligned IRFs when the FoV rotation is ignored
+    assert_allclose(
+        map_altaz_long_norotation.data,
+        map_short_altaz_norotation.data * 100,
+        rtol=1e-2,
+    )
+
+
 def test_make_edisp_kernel_map():
     migra = MapAxis.from_edges(np.linspace(0.5, 1.5, 50), unit="", name="migra")
     etrue = MapAxis.from_energy_bounds(0.5, 2, 6, unit="TeV", name="energy_true")
@@ -386,7 +483,7 @@ class TestTheta2Table:
             events["DEC"] = sign * ([0.0, 0.05, 0.9, 10.0, 10.0] * u.deg)
             events["ENERGY"] = [1.0, 1.0, 1.5, 1.5, 10.0] * u.TeV
             events["OFFSET"] = [0.1, 0.1, 0.5, 1.0, 1.5] * u.deg
-            events["TIME"] = [0.1, 0.2, 0.3, 0.4, 0.5] * u.s
+            events["TIME"] = Time("2025-01-01") + [0.1, 0.2, 0.3, 0.4, 0.5] * u.s
 
             obs_info = dict(
                 OBS_ID=0,
@@ -474,6 +571,34 @@ class TestTheta2Table:
         assert_allclose(theta2_table_two_obs["acceptance_off"], acceptance_off_two_obs)
         assert_allclose(theta2_table["alpha"], alpha_two_obs)
 
+        # Test for energy selection
+        axis = MapAxis.from_bounds(0, 1, nbin=4, interp="lin", unit="deg2")
+        theta2_table = make_theta_squared_table(
+            observations=[self.observations[0]],
+            position=position,
+            theta_squared_axis=axis,
+            energy_edges=[1.2, 11] * u.TeV,
+        )
+        on_counts = [0, 0, 0, 1]
+        off_counts = [1, 0, 0, 0]
+        acceptance = [1, 1, 1, 1]
+        acceptance_off = [1, 1, 1, 1]
+        alpha = [1, 1, 1, 1]
+        assert_allclose(theta2_table["counts"], on_counts)
+        assert_allclose(theta2_table["counts_off"], off_counts)
+        assert_allclose(theta2_table["acceptance"], acceptance)
+        assert_allclose(theta2_table["acceptance_off"], acceptance_off)
+        assert_allclose(theta2_table["alpha"], alpha)
+        assert_allclose(theta2_table.meta["Energy_filter"], [1.2, 11] * u.TeV)
+
+        with pytest.raises(ValueError):
+            make_theta_squared_table(
+                observations=[self.observations[0]],
+                position=position,
+                theta_squared_axis=axis,
+                energy_edges=[1.2, 11, 20] * u.TeV,
+            )
+
 
 @requires_data()
 def test_guess_instrument_fov(observations):
