@@ -1,7 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import copy
 import logging
-from functools import lru_cache
+from gammapy.utils.cache import cachemethod
 import numpy as np
 from astropy import units as u
 from astropy.coordinates import Angle, SkyCoord
@@ -36,9 +36,24 @@ from ..geom import Geom, pix_tuple_to_idx
 from ..utils import _check_width
 from ..wcs import WcsGeom
 
+log = logging.getLogger(__name__)
+
+
 __all__ = ["RegionGeom"]
 
 
+def _parse_regions(regions):
+    if isinstance(regions, str):
+        regions = Regions.parse(data=regions, format="ds9")
+    elif isinstance(regions, SkyRegion):
+        regions = [regions]
+    elif isinstance(regions, SkyCoord):
+        regions = [PointSkyRegion(center=regions)]
+    elif isinstance(regions, list) and len(regions) == 0:
+        regions = None
+    return regions
+
+
 class RegionGeom(Geom):
     """Map geometry representing a region on the sky.
 
@@ -60,6 +75,11 @@ class RegionGeom(Geom):
         quantities in the region. Default is "0.1 deg". This default
         value is adequate for the majority of use cases. If a WCS object
         is provided, the input of ``binsz_wcs`` is overridden.
+
+    Notes
+    -----
+    - For further explanation and examples, see :doc:`/user-guide/maps/regionmap`
+
     """
 
     is_regular = True
@@ -101,15 +121,6 @@ class RegionGeom(Geom):
         self._wcs = wcs
         self.ndim = len(self.data_shape)
 
-        # define cached methods
-        self.get_wcs_coord_and_weights = lru_cache()(self.get_wcs_coord_and_weights)
-
-    def __setstate__(self, state):
-        for key, value in state.items():
-            if key in ["get_wcs_coord_and_weights"]:
-                state[key] = lru_cache()(value)
-        self.__dict__ = state
-
     @property
     def frame(self):
         """Coordinate system, either Galactic ("galactic") or Equatorial ("icrs")."""
@@ -430,6 +441,7 @@ class RegionGeom(Geom):
         new_geom = RegionGeom(self.region, axes=self.axes, binsz_wcs=binsz)
         return new_geom
 
+    @cachemethod
     def get_wcs_coord_and_weights(self, factor=10):
         """Get the array of spatial coordinates and corresponding weights.
 
@@ -642,9 +654,12 @@ class RegionGeom(Geom):
             return TypeError(f"Cannot compare {type(self)} and {type(other)}")
 
         if self.data_shape != other.data_shape:
+            log.debug("RegionGeom data shape is not equal")
             return False
 
         axes_eq = self.axes.is_allclose(other.axes, rtol=rtol_axes, atol=atol_axes)
+        if not axes_eq:
+            log.debug("RegionGeom axes are not equal")
         # TODO: compare regions based on masks...
         regions_eq = True
         return axes_eq and regions_eq
@@ -732,14 +747,7 @@ class RegionGeom(Geom):
         geom : `RegionGeom`
             Region map geometry.
         """
-        if isinstance(regions, str):
-            regions = Regions.parse(data=regions, format="ds9")
-        elif isinstance(regions, SkyRegion):
-            regions = [regions]
-        elif isinstance(regions, SkyCoord):
-            regions = [PointSkyRegion(center=regions)]
-        elif isinstance(regions, list) and len(regions) == 0:
-            regions = None
+        regions = _parse_regions(regions)
 
         if regions:
             regions = regions_to_compound_region(regions)
@@ -856,9 +864,14 @@ class RegionGeom(Geom):
 
             for key, value in kwargs.items():
                 key_point = ARTIST_TO_LINE_PROPERTIES.get(key, None)
-                if key_point:
+                if key_point and key_point not in kwargs_point:
                     kwargs_point[key_point] = value
 
+            if "color" in kwargs:
+                kwargs_point.setdefault("color", kwargs["color"])
+            if "color" in kwargs_point:
+                kwargs_point["markeredgecolor"] = kwargs_point["color"]
+
             for region in compound_region_to_regions(self.region):
                 region_pix = region.to_pixel(wcs=ax.wcs)
 
