@@ -1,10 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Models and fitting."""
+
 from .covariance import Covariance
 from .fit import CovarianceResult, Fit, FitResult, OptimizeResult
 from .parameter import Parameter, Parameters, PriorParameter, PriorParameters
 from .scipy import stat_profile_ul_scipy
 from .selection import select_nested_models
+from .sampler import Sampler, SamplerResult
 
 __all__ = [
     "Covariance",
@@ -18,4 +20,6 @@ __all__ = [
     "PriorParameter",
     "PriorParameters",
     "stat_profile_ul_scipy",
+    "Sampler",
+    "SamplerResult",
 ]
