@@ -12,7 +12,7 @@ import matplotlib.pyplot as plt
 from gammapy.maps import Map, RegionGeom
 from gammapy.modeling import Covariance, Parameter, Parameters
 from gammapy.modeling.covariance import CovarianceMixin
-from gammapy.utils.scripts import from_yaml, make_name, make_path, to_yaml, write_yaml
+from gammapy.utils.scripts import from_yaml, make_path, to_yaml, write_yaml
 
 __all__ = ["Model", "Models", "DatasetModels", "ModelBase"]
 
@@ -20,7 +20,29 @@ __all__ = ["Model", "Models", "DatasetModels", "ModelBase"]
 log = logging.getLogger(__name__)
 
 
-def _set_link(shared_register, model):
+def _recursive_dict_filename_update(dict_, path):
+    """Update model filename to full path if exits."""
+    for key, value in dict_.items():
+        if isinstance(value, dict):
+            _recursive_dict_filename_update(value, path)
+        elif key == "filename":
+            filename = dict_[key]
+            if (path / filename).exists():
+                dict_[key] = path / filename
+
+
+def _recursive_model_filename_update(model, path):
+    """Update model filename to relative path if child of path."""
+    if hasattr(model, "filename") and path == make_path(model.filename).parent:
+        _, filename = split(model.filename)
+        model.filename = filename
+
+    if hasattr(model, "_models"):
+        for m in model._models:
+            _recursive_model_filename_update(m, path)
+
+
+def _set_model_link(shared_register, model):
     for param in model.parameters:
         name = param.name
         link_label = param._link_label_io
@@ -33,6 +55,23 @@ def _set_link(shared_register, model):
     return shared_register
 
 
+def _flatten_models(models):
+    flat_models = []
+    for model in models:
+        if hasattr(model, "_models"):
+            flat_models.extend(_flatten_models(model._models))
+        else:
+            flat_models.append(model)
+    return flat_models
+
+
+def _set_models_link(models):
+    shared_register = {}
+    flat_models = _flatten_models(models)
+    for model in flat_models:
+        shared_register = _set_model_link(shared_register, model)
+
+
 def _get_model_class_from_dict(data):
     """Get a model class from a dictionary."""
     from . import (
@@ -78,7 +117,7 @@ def _build_parameters_from_dict(data, default_parameters):
 
 
 def _check_name_unique(model, names):
-    """Check if a model is not duplicated"""
+    """Check if a model is not duplicated."""
     if model.name in names:
         raise (
             ValueError(
@@ -88,6 +127,36 @@ def _check_name_unique(model, names):
     return
 
 
+def _check_fov_background_models(models):
+    """
+    Check if a maximum of one `~gammapy.modeling.models.FoVBackgroundModel` is assigned to dataset
+    and returns a dictionary mapping `dataset_name` to the background model name.
+
+    Parameters
+    ----------
+    models : `~gammapy.modeling.models.Models`
+        List of Models
+
+    Returns
+    -------
+    bkg_model_mapping : dict
+        Dictionary mapping dataset name to `~gammapy.modeling.models.FoVBackgroundModel` name.
+    """
+    from . import FoVBackgroundModel
+
+    bkg_model_mapping = {}
+    for model in models:
+        if isinstance(model, FoVBackgroundModel):
+            for n in model.datasets_names:
+                if n not in bkg_model_mapping.keys():
+                    bkg_model_mapping[n] = model.name
+                else:
+                    raise ValueError(
+                        f"Only one FoVBackgroundModel per Dataset is permitted - already got one for {n}"
+                    )
+    return bkg_model_mapping
+
+
 def _write_models(
     models,
     path,
@@ -98,7 +167,7 @@ def _write_models(
     checksum=False,
     extra_dict=None,
 ):
-    """Write models to YAML file with additionnal informations using an `extra_dict`"""
+    """Write models to YAML file with additional information using an `extra_dict`."""
 
     base_path, _ = split(path)
     path = make_path(path)
@@ -134,6 +203,10 @@ class ModelBase:
         # Copy default parameters from the class to the instance
         default_parameters = self.default_parameters.copy()
 
+        for key in kwargs.keys():
+            if key != "covariance_data" and key not in default_parameters.names:
+                raise NameError(f"Unknown Parameter name '{key}'")
+
         for par in default_parameters:
             value = kwargs.get(par.name, par)
 
@@ -241,6 +314,7 @@ class ModelBase:
                     "error",
                     "interp",
                     "scale_method",
+                    "scale_transform",
                 ]:
                     default = init[item]
 
@@ -404,7 +478,10 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
             _check_name_unique(model, names=unique_names)
             unique_names.append(model.name)
 
+        self._background_models = _check_fov_background_models(models)
+
         self._models = models
+
         self._covar_file = None
 
         self._covariance = Covariance(self.parameters)
@@ -434,6 +511,11 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
         """List of model names."""
         return [m.name for m in self._models]
 
+    @property
+    def background_models(self):
+        """Dictionnary mapping of dataset names with their associated `~gammapy.modeling.models.FoVBackgroundModel` names."""
+        return self._background_models
+
     @classmethod
     def read(cls, filename, checksum=False):
         """Read from YAML file.
@@ -472,38 +554,34 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
     @classmethod
     def from_dict(cls, data, path=""):
         """Create from dictionary."""
-        from . import MODEL_REGISTRY, SkyModel
+        from . import MODEL_REGISTRY
+
+        path = make_path(path)
 
         models = []
-
         for component in data["components"]:
             model_cls = MODEL_REGISTRY.get_cls(component["type"])
+            _recursive_dict_filename_update(component, path)
             model = model_cls.from_dict(component)
+            _recursive_model_filename_update(model, path)
             models.append(model)
-
         models = cls(models)
 
         if "covariance" in data:
             filename = data["covariance"]
-            path = make_path(path)
             if not (path / filename).exists():
                 path, filename = split(filename)
+            try:
+                models.read_covariance(path, filename, format="ascii.fixed_width")
+            except ValueError as exception:
+                log.warning(
+                    "Impossible to read the covariance correctly: \n"
+                    f"{exception} \n "
+                    "Covariance will be created from errors and non-diagonal terms ignored."
+                )
 
-            models.read_covariance(path, filename, format="ascii.fixed_width")
+        _set_models_link(models)
 
-        shared_register = {}
-        for model in models:
-            if isinstance(model, SkyModel):
-                submodels = [
-                    model.spectral_model,
-                    model.spatial_model,
-                    model.temporal_model,
-                ]
-                for submodel in submodels:
-                    if submodel is not None:
-                        shared_register = _set_link(shared_register, submodel)
-            else:
-                shared_register = _set_link(shared_register, model)
         return models
 
     def write(
@@ -533,6 +611,9 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
             When True adds a CHECKSUM entry to the file.
             Default is False.
         """
+        path = make_path(path)
+        for m in self:
+            _recursive_model_filename_update(m, path)
         _write_models(
             self,
             path,
@@ -558,16 +639,7 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
 
     def update_link_label(self):
         """Update linked parameters labels used for serialisation and print."""
-        params_list = []
-        params_shared = []
-        for param in self.parameters:
-            if param not in params_list:
-                params_list.append(param)
-                params_list.append(param)
-            elif param not in params_shared:
-                params_shared.append(param)
-        for param in params_shared:
-            param._link_label_io = param.name + "@" + make_name()
+        self.parameters.update_link_label()
 
     def to_dict(self, full_output=False, overwrite_templates=False):
         """Convert to dictionary."""
@@ -712,11 +784,12 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
         models: `Models`
             Copied models.
         """
+        self.update_link_label()
         models = []
-
         for model in self:
             model_copy = model.copy(name=model.name, copy_data=copy_data)
             models.append(model_copy)
+        _set_models_link(models)
 
         return self.__class__(
             models=models, covariance_data=self.covariance.data.copy()
@@ -1064,7 +1137,6 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
         model : `~gammapy.modeling.models.TemplateSpectralModel`
             Template spectral model.
         """
-
         from . import TemplateSpectralModel
 
         energy = geom.axes[0].center
@@ -1097,19 +1169,28 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
 
         return SkyCoord(positions)
 
-    def to_regions(self):
+    def to_regions(self, size_factor=None, **kwargs):
         """Return a list of the regions for the spatial models.
 
+        Parameters
+        ----------
+        size_factor : float, optional
+            Factor applied to the size of the models.
+            If not specified, the defaults for the models will be used.
+        kwargs : dict, optional
+            Keyword arguments passed to ``model.spatial_model.to_region``.
+
         Returns
         -------
-        regions: list of `~regions.SkyRegion`
+        regions : list of `~regions.SkyRegion`
             Regions.
         """
         regions = []
-
+        if size_factor:
+            kwargs["size_factor"] = size_factor
         for model in self.select(tag="sky-model"):
             try:
-                region = model.spatial_model.to_region()
+                region = model.spatial_model.to_region(**kwargs)
                 regions.append(region)
             except AttributeError:
                 log.warning(
@@ -1126,12 +1207,14 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
         except IndexError:
             log.error("No spatial component in any model. Geom not defined")
 
-    def plot_regions(self, ax=None, kwargs_point=None, path_effect=None, **kwargs):
+    def plot_regions(
+        self, ax=None, kwargs_point=None, path_effect=None, size_factor=None, **kwargs
+    ):
         """Plot extent of the spatial models on a given WCS axis.
 
         Parameters
         ----------
-        ax : `~astropy.visualization.WCSAxes`, optional
+        ax : `~astropy.visualization.wcsaxes.WCSAxes`, optional
             Axes to plot on. If no axes are given, an all-sky WCS
             is chosen using a CAR projection. Default is None.
         kwargs_point : dict, optional
@@ -1139,16 +1222,31 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
             of point sources. Default is None.
         path_effect : `~matplotlib.patheffects.PathEffect`, optional
             Path effect applied to artists and lines. Default is None.
+        size_factor : float, optional
+            Factor applied to the size of the model
+            If not specified, the defaults for the models will be used.
         **kwargs : dict
             Keyword arguments passed to `~matplotlib.artists.Artist`.
 
-
         Returns
         -------
-        ax : `~astropy.visualization.WcsAxes`
+        ax : `~astropy.visualization.wcsaxes.WCSAxes`
             WCS axes.
+
+        Examples
+        --------
+        >>> from gammapy.datasets import MapDataset
+        >>> from gammapy.catalog import SourceCatalog3FHL
+        >>> fermi_dataset = MapDataset.read(
+        ...    "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc.fits.gz", name="fermi_dataset")
+        >>> catalog = SourceCatalog3FHL()
+        >>> models = catalog.to_models().select_from_geom(fermi_dataset.geoms["geom"])
+        >>> ax = fermi_dataset.excess.sum_over_axes().smooth("0.2 deg").plot(add_cbar=True, cmap="Blues")
+        >>> ax = models.plot_regions(ax=ax, linewidth=1,  color="red",
+        ...    kwargs_point={"marker":"o", "markersize":5, "color":"red"}
+        ...            )
         """
-        regions = self.to_regions()
+        regions = self.to_regions(size_factor=size_factor)
 
         geom = RegionGeom.from_regions(regions=regions)
         return geom.plot_region(
@@ -1171,6 +1269,19 @@ class DatasetModels(collections.abc.Sequence, CovarianceMixin):
         -------
         ax : `~astropy.visualization.WcsAxes`
             WCS axes.
+
+        Examples
+        --------
+
+        >>> from gammapy.datasets import MapDataset
+        >>> from gammapy.catalog import SourceCatalog3FHL
+        >>> fermi_dataset = MapDataset.read(
+        ...        "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc.fits.gz", name="fermi_dataset"
+        ...        )
+        >>> catalog = SourceCatalog3FHL()
+        >>> models = catalog.to_models().select_from_geom(fermi_dataset.geoms["geom"])
+        >>> ax = fermi_dataset.excess.sum_over_axes().smooth("0.2 deg").plot(add_cbar=True, cmap="Blues")
+        >>> ax = models.plot_positions(ax=ax, color="red", marker="+", linewidth=1)
         """
         from astropy.visualization.wcsaxes import WCSAxes
 
@@ -1201,6 +1312,7 @@ class Models(DatasetModels, collections.abc.MutableSequence):
 
     def __delitem__(self, key):
         del self._models[self.index(key)]
+        self._background_models = _check_fov_background_models(self._models)
 
     def __setitem__(self, key, model):
         from gammapy.modeling.models import (
@@ -1210,13 +1322,17 @@ class Models(DatasetModels, collections.abc.MutableSequence):
         )
 
         if isinstance(model, (SkyModel, FoVBackgroundModel, TemplateNPredModel)):
-            self._models[self.index(key)] = model
+            ind = self.index(key)
+            other_names = [_ for _ in self.names if _ != self._models[ind].name]
+            _check_name_unique(model, other_names)
+            self._models[ind] = model
         else:
             raise TypeError(f"Invalid type: {model!r}")
 
     def insert(self, idx, model):
         _check_name_unique(model, self.names)
         self._models.insert(idx, model)
+        self._background_models = _check_fov_background_models(self._models)
 
     def set_prior(self, parameters, priors):
         for parameter, prior in zip(parameters, priors):
