@@ -4,10 +4,17 @@
 import logging
 import numpy as np
 import astropy.units as u
+from scipy.stats import norm, uniform, loguniform, gennorm
 from gammapy.modeling import PriorParameter, PriorParameters
 from .core import ModelBase
 
-__all__ = ["GaussianPrior", "UniformPrior", "Prior"]
+__all__ = [
+    "GaussianPrior",
+    "GeneralizedGaussianPrior",
+    "UniformPrior",
+    "LogUniformPrior",
+    "Prior",
+]
 
 log = logging.getLogger(__name__)
 
@@ -34,7 +41,12 @@ def _build_priorparameters_from_dict(data, default_parameters):
 
 
 class Prior(ModelBase):
-    """Prior base class."""
+    """Prior abstract base class. For now, see existing examples of type of priors:
+
+    - `GaussianPrior`
+    - `UniformPrior`
+    - `LogUniformPrior`
+    """
 
     _unit = ""
 
@@ -71,9 +83,13 @@ class Prior(ModelBase):
             [_ for _ in cls.__dict__.values() if isinstance(_, PriorParameter)]
         )
 
+    def _inverse_cdf(self, value):
+        """Return inverse CDF for prior."""
+        return self._random_variable.ppf(value)
+
     @property
     def weight(self):
-        """Weight mulitplied to the prior when evaluated."""
+        """Weight multiplied to the prior when evaluated."""
         return self._weight
 
     @weight.setter
@@ -82,7 +98,7 @@ class Prior(ModelBase):
 
     def __call__(self, value):
         """Call evaluate method."""
-        # assuming the same unit as the PriorParamater here
+        # assuming the same unit as the PriorParameter here
         kwargs = {par.name: par.value for par in self.parameters}
         return self.weight * self.evaluate(value.value, **kwargs)
 
@@ -138,10 +154,10 @@ class GaussianPrior(Prior):
 
     Parameters
     ----------
-    mu : float
+    mu : float, optional
         Mean of the Gaussian distribution.
         Default is 0.
-    sigma : float
+    sigma : float, optional
         Standard deviation of the Gaussian distribution.
         Default is 1.
     """
@@ -154,34 +170,118 @@ class GaussianPrior(Prior):
     @staticmethod
     def evaluate(value, mu, sigma):
         """Evaluate the Gaussian prior."""
-        return ((value - mu) / sigma) ** 2
+        rv = norm(mu, sigma)
+        return -2 * rv.logpdf(value)
+
+    @property
+    def _random_variable(self):
+        """Return random variable object for prior."""
+        return norm(self.mu.value, self.sigma.value)
 
 
 class UniformPrior(Prior):
     """Uniform Prior.
 
-    Returns 1 if the parameter value is in (min, max).
-    0, if otherwise.
+    Returns 2log(max-min) if the parameter value is in [min, max].
+    Returns inf, otherwise.
+    Only well defined for finite values of min and max.
 
     Parameters
     ----------
-    min : float
+    min : float, optional
         Minimum value.
-        Default is -inf.
-    max : float
-        Maxmimum value.
-        Default is inf.
+        Default is 0.
+    max : float, optional
+        Maximum value.
+        Default is 1.
     """
 
     tag = ["UniformPrior"]
     _type = "prior"
-    min = PriorParameter(name="min", value=-np.inf, unit="")
-    max = PriorParameter(name="max", value=np.inf, unit="")
+    min = PriorParameter(name="min", value=0.0, unit="")
+    max = PriorParameter(name="max", value=1.0, unit="")
 
     @staticmethod
     def evaluate(value, min, max):
         """Evaluate the uniform prior."""
-        if min < value < max:
-            return 0.0
-        else:
-            return 1.0
+        rv = uniform(min, max - min)
+        return -2 * rv.logpdf(value)
+
+    @property
+    def _random_variable(self):
+        """Return random variable object for prior."""
+        return uniform(self.min.value, self.max.value - self.min.value)
+
+
+class LogUniformPrior(Prior):
+    """LogUniform Prior.
+
+    Equivalent to a uniform prior on the log of the parameter
+
+    Parameters
+    ----------
+    min : float, optional
+        Minimum value. Default is 1e-14.
+    max : float, optional
+        Maximum value. Default is 1e-10.
+    """
+
+    tag = ["LogUniformPrior"]
+    _type = "prior"
+    min = PriorParameter(name="min", value=1e-14, unit="")
+    max = PriorParameter(name="max", value=1e-10, unit="")
+
+    @staticmethod
+    def evaluate(value, min, max):
+        """
+        Evaluate the likelihood penalization term (hence -2*).
+        Note that this is currently a different scaling that the Uniform or Gaussian priors.
+        With current implementation the TS of a source with/without LogUniform prior would be different... TBD
+        """
+        rv = loguniform(min, max)
+        return -2 * rv.logpdf(value)
+
+    @property
+    def _random_variable(self):
+        """Return random variable object for prior."""
+        return loguniform(self.min.value, self.max.value)
+
+
+class GeneralizedGaussianPrior(Prior):
+    """One-dimensional Generalized Gaussian Prior.
+
+    Parameters
+    ----------
+    mu : float, optional
+        Mean of the Gaussian distribution.
+        Default is 0.
+    sigma : float, optional
+        Standard deviation of the Gaussian distribution.
+        Default is 1.
+    eta : `float`, optional
+        eta is a shape parameter
+        For eta=1 it is identical to a Laplace distribution (scaled by sqrt(2)).
+        For eta=0.5 it is identical to a normal distribution.
+        Default is 0.5.
+    """
+
+    tag = ["GeneralizedGaussianPrior"]
+    _type = "prior"
+    mu = PriorParameter(name="mu", value=0)
+    sigma = PriorParameter(name="sigma", value=1)
+    eta = PriorParameter(name="eta", value=0.5)
+
+    @staticmethod
+    def evaluate(value, mu, sigma, eta):
+        """Evaluate the Gaussian prior."""
+        rv = gennorm(beta=1.0 / eta, loc=mu, scale=sigma * np.sqrt(2))
+        return -2 * rv.logpdf(value)
+
+    @property
+    def _random_variable(self):
+        """Return random variable object for prior."""
+        return gennorm(
+            beta=1.0 / self.eta.value,
+            loc=self.mu.value,
+            scale=self.sigma.value * np.sqrt(2),
+        )
