@@ -28,6 +28,8 @@ from gammapy.utils.interpolation import interpolation_scale
 from gammapy.utils.regions import region_circle_to_ellipse, region_to_frame
 from gammapy.utils.scripts import make_path
 from .core import ModelBase, _build_parameters_from_dict
+from gammapy.utils.units import wrap_at
+from gammapy.utils.deprecation import deprecated_renamed_argument
 
 __all__ = [
     "ConstantFluxSpatialModel",
@@ -589,6 +591,7 @@ class PointSpatialModel(SpatialModel):
 
     def to_region(self, **kwargs):
         """Model outline as a `~regions.PointSkyRegion`."""
+        kwargs.pop("size_factor", None)
         return PointSkyRegion(center=self.position, **kwargs)
 
 
@@ -606,10 +609,10 @@ class GaussianSpatialModel(SpatialModel):
         Length of the major semiaxis of the Gaussian, in angular units.
         Default is 1 deg.
     e : `float`
-        Eccentricity of the Gaussian (:math:`0< e< 1`).
+        Eccentricity of the Gaussian (:math:`0<= e<= 1`).
         Default is 0.
     phi : `~astropy.coordinates.Angle`
-        Rotation angle :math:`\phi`: of the major semiaxis.
+        Rotation angle :math:`\phi`: of the major semiaxis (:math:`-180 <= phi <= 180`).
         Increases counter-clockwise from the North direction.
         Default is 0 deg.
     frame : {"icrs", "galactic"}
@@ -622,7 +625,7 @@ class GaussianSpatialModel(SpatialModel):
     lat_0 = Parameter("lat_0", "0 deg", min=-90, max=90)
     sigma = Parameter("sigma", "1 deg", min=0)
     e = Parameter("e", 0, min=0, max=1, frozen=True)
-    phi = Parameter("phi", "0 deg", frozen=True)
+    phi = Parameter("phi", "0 deg", frozen=True, min=-180, max=180)
 
     @property
     def evaluation_bin_size_min(self):
@@ -641,6 +644,7 @@ class GaussianSpatialModel(SpatialModel):
     def evaluate(lon, lat, lon_0, lat_0, sigma, e, phi):
         """Evaluate model."""
         sep = angular_separation(lon, lat, lon_0, lat_0)
+        phi = wrap_at(phi, 0 * u.deg, 180 * u.deg)
 
         if e == 0:
             a = 1.0 - np.cos(sigma)
@@ -655,14 +659,15 @@ class GaussianSpatialModel(SpatialModel):
         exponent = -0.5 * ((1 - np.cos(sep)) / a)
         return u.Quantity(norm * np.exp(exponent).value, "sr-1", copy=COPY_IF_NEEDED)
 
-    def to_region(self, x_sigma=1.5, **kwargs):
+    @deprecated_renamed_argument("x_sigma", "size_factor", "2.0")
+    def to_region(self, size_factor=1.0, **kwargs):
         r"""Model outline at a given number of :math:`\sigma`.
 
         Parameters
         ----------
-        x_sigma : float
+        size_factor : float
             Number of :math:`\sigma
-            Default is :math:`1.5\sigma` which corresponds to about 68%
+            Default is :math:`1.0\sigma` which corresponds to about 39%
             containment for a 2D symmetric Gaussian.
 
         Returns
@@ -673,8 +678,8 @@ class GaussianSpatialModel(SpatialModel):
         minor_axis = Angle(self.sigma.quantity * np.sqrt(1 - self.e.quantity**2))
         return EllipseSkyRegion(
             center=self.position,
-            height=2 * x_sigma * self.sigma.quantity,
-            width=2 * x_sigma * minor_axis,
+            height=2 * size_factor * self.sigma.quantity,
+            width=2 * size_factor * minor_axis,
             angle=self.phi.quantity,
             **kwargs,
         )
@@ -682,15 +687,16 @@ class GaussianSpatialModel(SpatialModel):
     @property
     def evaluation_region(self):
         """Evaluation region consistent with evaluation radius."""
-        return self.to_region(x_sigma=5)
+        return self.to_region(size_factor=5)
 
-    def _to_region_error(self, x_sigma=1.5):
+    @deprecated_renamed_argument("x_sigma", "size_factor", "2.0")
+    def _to_region_error(self, size_factor=1.5):
         r"""Plot model error at a given number of :math:`\sigma`.
 
         Parameters
         ----------
-        x_sigma : float
-            Number of :math:`\sigma
+        size_factor : float
+            Number of :math:`\sigma`
             Default is :math:`1.5\sigma` which corresponds to about 68%
             containment for a 2D symmetric Gaussian.
 
@@ -711,10 +717,10 @@ class GaussianSpatialModel(SpatialModel):
 
         return EllipseAnnulusSkyRegion(
             center=self.position,
-            inner_height=2 * x_sigma * sigma_lo,
-            outer_height=2 * x_sigma * sigma_hi,
-            inner_width=2 * x_sigma * minor_axis_lo,
-            outer_width=2 * x_sigma * minor_axis_hi,
+            inner_height=2 * size_factor * sigma_lo,
+            outer_height=2 * size_factor * sigma_hi,
+            inner_width=2 * size_factor * minor_axis_lo,
+            outer_width=2 * size_factor * minor_axis_hi,
             angle=self.phi.quantity,
         )
 
@@ -736,10 +742,10 @@ class GeneralizedGaussianSpatialModel(SpatialModel):
         Shape parameter within (0, 1). Special cases for disk: ->0, Gaussian: 0.5, Laplace:1
         Default is 0.5.
     e : `float`
-        Eccentricity (:math:`0< e< 1`).
+        Eccentricity (:math:`0<= e< =1`).
         Default is 0.
     phi : `~astropy.coordinates.Angle`
-        Rotation angle :math:`\phi`: of the major semiaxis.
+        Rotation angle :math:`\phi`: of the major semiaxis (:math:`-180<=phi<=180`).
         Increases counter-clockwise from the North direction.
         Default is 0 deg.
     frame : {"icrs", "galactic"}
@@ -752,10 +758,11 @@ class GeneralizedGaussianSpatialModel(SpatialModel):
     r_0 = Parameter("r_0", "1 deg")
     eta = Parameter("eta", 0.5, min=0.01, max=1.0)
     e = Parameter("e", 0.0, min=0.0, max=1.0, frozen=True)
-    phi = Parameter("phi", "0 deg", frozen=True)
+    phi = Parameter("phi", "0 deg", frozen=True, min=-180, max=180)
 
     @staticmethod
     def evaluate(lon, lat, lon_0, lat_0, r_0, eta, e, phi):
+        phi = wrap_at(phi, 0 * u.deg, 180 * u.deg)
         sep = angular_separation(lon, lat, lon_0, lat_0)
         if isinstance(eta, u.Quantity):
             eta = eta.value  # gamma function does not allow quantities
@@ -784,13 +791,14 @@ class GeneralizedGaussianSpatialModel(SpatialModel):
         """
         return self.r_0.quantity * (1 + 8 * self.eta.value)
 
-    def to_region(self, x_r_0=1, **kwargs):
+    @deprecated_renamed_argument("x_r_0", "size_factor", "2.0")
+    def to_region(self, size_factor=1, **kwargs):
         r"""Model outline at a given number of :math:`r_0`.
 
         Parameters
         ----------
-        x_r_0 : float, optional
-            Number of :math:`r_0`. Default is 1.
+        size_factor : float, optional
+            Number of :math:`r_0`. Default is 1.0
 
         Returns
         -------
@@ -800,8 +808,8 @@ class GeneralizedGaussianSpatialModel(SpatialModel):
         minor_axis = Angle(self.r_0.quantity * np.sqrt(1 - self.e.quantity**2))
         return EllipseSkyRegion(
             center=self.position,
-            height=2 * x_r_0 * self.r_0.quantity,
-            width=2 * x_r_0 * minor_axis,
+            height=2 * size_factor * self.r_0.quantity,
+            width=2 * size_factor * minor_axis,
             angle=self.phi.quantity,
             **kwargs,
         )
@@ -810,14 +818,14 @@ class GeneralizedGaussianSpatialModel(SpatialModel):
     def evaluation_region(self):
         """Evaluation region consistent with evaluation radius."""
         scale = self.evaluation_radius / self.r_0.quantity
-        return self.to_region(x_r_0=scale)
+        return self.to_region(size_factor=scale)
 
-    def _to_region_error(self, x_r_0=1):
+    def _to_region_error(self, size_factor=1):
         r"""Model error at a given number of :math:`r_0`.
 
         Parameters
         ----------
-        x_r_0 : float, optional
+        size_factor : float, optional
             Number of :math:`r_0`. Default is 1.
 
         Returns
@@ -837,10 +845,10 @@ class GeneralizedGaussianSpatialModel(SpatialModel):
 
         return EllipseAnnulusSkyRegion(
             center=self.position,
-            inner_height=2 * x_r_0 * r_0_lo,
-            outer_height=2 * x_r_0 * r_0_hi,
-            inner_width=2 * x_r_0 * minor_axis_lo,
-            outer_width=2 * x_r_0 * minor_axis_hi,
+            inner_height=2 * size_factor * r_0_lo,
+            outer_height=2 * size_factor * r_0_hi,
+            inner_width=2 * size_factor * minor_axis_lo,
+            outer_width=2 * size_factor * minor_axis_hi,
             angle=self.phi.quantity,
         )
 
@@ -859,10 +867,10 @@ class DiskSpatialModel(SpatialModel):
         :math:`a`: length of the major semiaxis, in angular units.
         Default is 1 deg.
     e : `float`
-        Eccentricity of the ellipse (:math:`0< e< 1`).
+        Eccentricity of the ellipse (:math:`0<= e<= 1`).
         Default is 0.
     phi : `~astropy.coordinates.Angle`
-        Rotation angle :math:`\phi`: of the major semiaxis.
+        Rotation angle :math:`\phi`: of the major semiaxis (:math:`-180<=phi<=200`).
         Increases counter-clockwise from the North direction.
         Default is 0 deg.
     edge_width : float
@@ -879,7 +887,7 @@ class DiskSpatialModel(SpatialModel):
     lat_0 = Parameter("lat_0", "0 deg", min=-90, max=90)
     r_0 = Parameter("r_0", "1 deg", min=0)
     e = Parameter("e", 0, min=0, max=1, frozen=True)
-    phi = Parameter("phi", "0 deg", frozen=True)
+    phi = Parameter("phi", "0 deg", frozen=True, min=-180, max=180)
     edge_width = Parameter("edge_width", value=0.01, min=0, max=1, frozen=True)
 
     @property
@@ -928,6 +936,7 @@ class DiskSpatialModel(SpatialModel):
     def evaluate(lon, lat, lon_0, lat_0, r_0, e, phi, edge_width):
         """Evaluate model."""
         sep = angular_separation(lon, lat, lon_0, lat_0)
+        phi = wrap_at(phi, 0 * u.deg, 180 * u.deg)
 
         if e == 0:
             sigma_eff = r_0
@@ -941,13 +950,13 @@ class DiskSpatialModel(SpatialModel):
         )
         return u.Quantity(norm * in_ellipse, "sr-1", copy=COPY_IF_NEEDED)
 
-    def to_region(self, **kwargs):
+    def to_region(self, size_factor=1.0, **kwargs):
         """Model outline as a `~regions.EllipseSkyRegion`."""
         minor_axis = Angle(self.r_0.quantity * np.sqrt(1 - self.e.quantity**2))
         return EllipseSkyRegion(
             center=self.position,
-            height=2 * self.r_0.quantity,
-            width=2 * minor_axis,
+            height=2 * size_factor * self.r_0.quantity,
+            width=2 * size_factor * minor_axis,
             angle=self.phi.quantity,
             **kwargs,
         )
@@ -1083,12 +1092,12 @@ class ShellSpatialModel(SpatialModel):
 
         return norm * value
 
-    def to_region(self, **kwargs):
+    def to_region(self, size_factor=1.0, **kwargs):
         """Model outline as a `~regions.CircleAnnulusSkyRegion`."""
         return CircleAnnulusSkyRegion(
             center=self.position,
-            inner_radius=self.radius.quantity,
-            outer_radius=self.radius.quantity + self.width.quantity,
+            inner_radius=size_factor * self.radius.quantity,
+            outer_radius=size_factor * (self.radius.quantity + self.width.quantity),
             **kwargs,
         )
 
@@ -1161,12 +1170,12 @@ class Shell2SpatialModel(SpatialModel):
 
         return norm * value
 
-    def to_region(self, **kwargs):
+    def to_region(self, size_factor=1.0, **kwargs):
         """Model outline as a `~regions.CircleAnnulusSkyRegion`."""
         return CircleAnnulusSkyRegion(
             center=self.position,
-            inner_radius=self.r_in,
-            outer_radius=self.r_0.quantity,
+            inner_radius=size_factor * self.r_in,
+            outer_radius=size_factor * self.r_0.quantity,
             **kwargs,
         )
 
@@ -1204,6 +1213,7 @@ class ConstantSpatialModel(SpatialModel):
 
     def to_region(self, **kwargs):
         """Model outline as a `~regions.RectangleSkyRegion`."""
+        kwargs.pop("size_factor", None)
         return RectangleSkyRegion(
             center=SkyCoord(0 * u.deg, 0 * u.deg, frame=self.frame),
             height=180 * u.deg,
@@ -1249,6 +1259,7 @@ class ConstantFluxSpatialModel(SpatialModel):
 
     def to_region(self, **kwargs):
         """Model outline as a `~regions.RectangleSkyRegion`."""
+        kwargs.pop("size_factor", None)
         return RectangleSkyRegion(
             center=SkyCoord(0 * u.deg, 0 * u.deg, frame=self.frame),
             height=180 * u.deg,
@@ -1315,9 +1326,14 @@ class TemplateSpatialModel(SpatialModel):
 
         if filename is not None:
             filename = str(make_path(filename))
+        if filename is None:
+            log.warning(
+                "The filename is not defined. Therefore, the model will not be serialised correctly. "
+                'To set the filename, the "template_model.filename" attribute can be used.'
+            )
+        self.filename = filename
 
         self.normalize = normalize
-
         if normalize:
             # Normalize the diffuse map model so that it integrates to unity
             if map.geom.is_image:
@@ -1352,7 +1368,6 @@ class TemplateSpatialModel(SpatialModel):
         interp_kwargs.setdefault("values_scale", "log")
 
         self._interp_kwargs = interp_kwargs
-        self.filename = filename
         kwargs["frame"] = self.map.geom.frame
         if "lon_0" not in kwargs or (
             isinstance(kwargs["lon_0"], Parameter) and np.isnan(kwargs["lon_0"].value)
@@ -1456,7 +1471,6 @@ class TemplateSpatialModel(SpatialModel):
         Note that, if the map data assume negative values, these are
         clipped to zero.
         """
-
         offset_lon = 0.0 * u.deg if lon_0 is None else lon_0 - self.map_center.data.lon
         offset_lat = 0.0 * u.deg if lat_0 is None else lat_0 - self.map_center.data.lat
 
@@ -1493,7 +1507,7 @@ class TemplateSpatialModel(SpatialModel):
         return cls(m, normalize=normalize, filename=filename, **kwargs)
 
     def to_dict(self, full_output=False):
-        """Create dictionary for YAML serilisation."""
+        """Create dictionary for YAML serialisation."""
         data = super().to_dict(full_output)
         data["spatial"]["filename"] = self.filename
         data["spatial"]["normalize"] = self.normalize
@@ -1506,10 +1520,10 @@ class TemplateSpatialModel(SpatialModel):
 
         Parameters
         ----------
-        overwrite: bool, optional
+        overwrite : bool, optional
             Overwrite existing file.
             Default is False, which will raise a warning if the template file exists already.
-        filename: str, optional
+        filename : str, optional
             Filename of the template model. By default, the template model
             will be saved with the `TemplateSpatialModel.filename` attribute,
             if `filename` is provided this attribute will be updated.
@@ -1525,6 +1539,7 @@ class TemplateSpatialModel(SpatialModel):
 
     def to_region(self, **kwargs):
         """Model outline from template map boundary as a `~regions.RectangleSkyRegion`."""
+        kwargs.pop("size_factor", None)
         return RectangleSkyRegion(
             center=self.map.geom.center_skydir,
             width=self.map.geom.width[0][0],
@@ -1580,6 +1595,11 @@ class TemplateNDSpatialModel(SpatialModel):
         self.meta = dict() if meta is None else meta
         if filename is not None:
             filename = str(make_path(filename))
+        if filename is None:
+            log.warning(
+                "The filename is not defined. Therefore, the model will not be serialised correctly. "
+                'To set the filename, the "template_model.filename" attribute can be used.'
+            )
         self.filename = filename
 
         parameters = []
@@ -1629,22 +1649,28 @@ class TemplateNDSpatialModel(SpatialModel):
 
         return u.Quantity(val, self.map.unit, copy=COPY_IF_NEEDED)
 
-    def write(self, overwrite=False):
+    def write(self, overwrite=False, filename=None):
         """
         Write the map.
 
         Parameters
         ----------
-        overwrite: bool, optional
+        overwrite : bool, optional
             Overwrite existing file.
             Default is False, which will raise a warning if the template file exists already.
+        filename : str, optional
+            Filename of the template model. By default, the template model
+            will be saved with the `TemplateNDSpatialModel.filename` attribute.
+            If `filename` is provided, this attribute will be used.
         """
+        if filename is not None:
+            self.filename = filename
         if self.filename is None:
             raise IOError("Missing filename")
-        elif os.path.isfile(self.filename) and not overwrite:
+        if os.path.isfile(make_path(self.filename)) and not overwrite:
             log.warning("Template file already exits, and overwrite is False")
         else:
-            self.map.write(self.filename)
+            self.map.write(self.filename, overwrite=overwrite)
 
     @classmethod
     def from_dict(cls, data):
@@ -1675,7 +1701,7 @@ class PiecewiseNormSpatialModel(SpatialModel):
     ----------
     coord : `gammapy.maps.MapCoord`
         Flat coordinates list at which the model values are given (nodes).
-    norms : `~numpy.ndarray` or list of `Parameter`
+    norms : `~numpy.ndarray` or list of `gammapy.modeling.Parameter`
         Array with the initial norms of the model at energies ``energy``.
         Normalisation parameters are created for each value.
         Default is one at each node.
