@@ -19,15 +19,18 @@ from gammapy.modeling.models import (
     Model,
     Models,
     PiecewiseNormSpectralModel,
+    PointSpatialModel,
+    PowerLawNormSpectralModel,
     PowerLawSpectralModel,
     PowerLawTemporalModel,
     SineTemporalModel,
     SkyModel,
     TemplateNPredModel,
 )
-from gammapy.utils.deprecation import GammapyDeprecationWarning
 from gammapy.utils.scripts import make_path, read_yaml, to_yaml, write_yaml
-from gammapy.utils.testing import requires_data, requires_dependency
+from gammapy.utils.testing import requires_data
+import os
+import importlib
 
 
 @pytest.fixture(scope="session")
@@ -151,7 +154,8 @@ def test_sky_models_checksum(tmpdir, models):
 @requires_data()
 def test_sky_models_io_auto_write(tmp_path, models):
     models_new = models.copy()
-    fsource2 = str(tmp_path / "source2_test.fits")
+    os.chdir(tmp_path)
+    fsource2 = str("source2_test.fits")
     fbkg_iem = str(tmp_path / "cube_iem_test.fits")
     fbkg_irf = str(tmp_path / "background_irf_test.fits")
 
@@ -160,11 +164,12 @@ def test_sky_models_io_auto_write(tmp_path, models):
     models_new["background_irf"].filename = fbkg_irf
     models_new.write(tmp_path / "tmp.yaml", full_output=True)
 
+    os.chdir("..")
     models = Models.read(tmp_path / "tmp.yaml")
     assert models._covar_file == "tmp_covariance.dat"
     assert models["source2"].spatial_model.filename == fsource2
-    assert models["cube_iem"].spatial_model.filename == fbkg_iem
-    assert models["background_irf"].filename == fbkg_irf
+    assert models["cube_iem"].spatial_model.filename == "cube_iem_test.fits"
+    assert models["background_irf"].filename == "background_irf_test.fits"
 
     assert_allclose(
         models_new["source2"].spatial_model.map.data,
@@ -230,8 +235,8 @@ def test_absorption_io_invalid_path(tmp_path):
     model_dict = dominguez.to_dict()
     parnames = [_["name"] for _ in model_dict["spectral"]["parameters"]]
     assert parnames == [
-        "alpha_norm",
         "redshift",
+        "alpha_norm",
     ]
     new_model = EBLAbsorptionNormSpectralModel.from_dict(model_dict)
 
@@ -257,8 +262,8 @@ def test_absorption_io_no_filename(tmp_path):
     model_dict = dominguez.to_dict()
     parnames = [_["name"] for _ in model_dict["spectral"]["parameters"]]
     assert parnames == [
-        "alpha_norm",
         "redshift",
+        "alpha_norm",
     ]
 
     new_model = EBLAbsorptionNormSpectralModel.from_dict(model_dict)
@@ -279,8 +284,8 @@ def test_absorption_io(tmp_path):
     model_dict = dominguez.to_dict()
     parnames = [_["name"] for _ in model_dict["spectral"]["parameters"]]
     assert parnames == [
-        "alpha_norm",
         "redshift",
+        "alpha_norm",
     ]
 
     new_model = EBLAbsorptionNormSpectralModel.from_dict(model_dict)
@@ -310,19 +315,6 @@ def test_absorption_io(tmp_path):
     read_yaml(tmp_path / "tmp.yaml")
 
 
-@requires_dependency("naima")
-def test_naima_model():
-    import naima
-
-    particle_distribution = naima.models.PowerLaw(
-        amplitude=2e33 / u.eV, e_0=10 * u.TeV, alpha=2.5
-    )
-    radiative_model = naima.radiative.PionDecay(particle_distribution, nh=1 * u.cm**-3)
-    yield Model.create(
-        "NaimaSpectralModel", "spectral", radiative_model=radiative_model
-    )
-
-
 def make_all_models():
     """Make an instance of each model, for testing."""
     yield Model.create("ConstantSpatialModel", "spatial")
@@ -353,8 +345,7 @@ def make_all_models():
     yield Model.create("PowerLawNormSpectralModel", "spectral")
     yield Model.create("PowerLaw2SpectralModel", "spectral")
     yield Model.create("ExpCutoffPowerLawSpectralModel", "spectral")
-    with pytest.warns(GammapyDeprecationWarning):
-        yield Model.create("ExpCutoffPowerLawNormSpectralModel", "spectral")
+    yield Model.create("ExpCutoffPowerLawNormSpectralModel", "spectral")
     yield Model.create("ExpCutoffPowerLaw3FGLSpectralModel", "spectral")
     yield Model.create("SuperExpCutoffPowerLaw3FGLSpectralModel", "spectral")
     yield Model.create("SuperExpCutoffPowerLaw4FGLDR3SpectralModel", "spectral")
@@ -400,6 +391,19 @@ def make_all_models():
     )
     yield Model.create("TemplateNPredModel", map=m2)
 
+    if importlib.util.find_spec("naima"):
+        import naima
+
+        particle_distribution = naima.models.PowerLaw(
+            amplitude=2e33 / u.eV, e_0=10 * u.TeV, alpha=2.5
+        )
+        radiative_model = naima.radiative.PionDecay(
+            particle_distribution, nh=1 * u.cm**-3
+        )
+        yield Model.create(
+            "NaimaSpectralModel", "spectral", radiative_model=radiative_model
+        )
+
 
 @pytest.mark.parametrize("model_class", MODEL_REGISTRY)
 def test_all_model_classes(model_class):
@@ -471,6 +475,60 @@ def test_link_label(models):
             n_link += 1
     assert n_link == 2
 
+    table = skymodels.parameters.to_table()
+    skymodels_copy = skymodels.copy()
+    assert (
+        skymodels_copy[0].spectral_model.reference
+        == skymodels_copy[1].spectral_model.reference
+    )
+    dict_ = skymodels_copy.to_dict()
+    label0 = dict_["components"][0]["spectral"]["parameters"][2]["link"]
+    label1 = dict_["components"][1]["spectral"]["parameters"][2]["link"]
+    assert label0 == label1
+
+    assert table["link"][2] == table["link"][9] and table["link"][2] != table["link"][1]
+
+    txt = skymodels.__str__()
+    lines = txt.splitlines()  # noqa: E303
+    n_link = 0
+    for line in lines:
+        if "@" in line:
+            assert "reference" in line
+            n_link += 1
+    assert n_link == 2
+
+
+def test_link_label_compound():
+    shared_pl = PowerLawSpectralModel(
+        index=2.2, amplitude="1e-12 cm-2 s-1 TeV-1", reference="1 TeV"
+    )
+    shared_point = PointSpatialModel()
+    norm1 = PowerLawNormSpectralModel(norm=1.0, tilt=0.0)
+    norm2 = PowerLawNormSpectralModel(norm=0.5, tilt=0.0)
+    model1 = SkyModel(
+        name="model-1", spatial_model=shared_point, spectral_model=shared_pl * norm1
+    )
+    model2 = SkyModel(
+        name="model-2",
+        spatial_model=shared_point,
+        spectral_model=shared_pl * norm2 * norm1,
+    )
+    models = Models([model1, model2])
+
+    assert len(models.parameters.free_unique_parameters.to_table()) == 6
+    assert len(models.parameters.free_unique_parameters) == 6
+
+    models_copy = models.copy()
+    assert len(models_copy.parameters.free_unique_parameters.to_table()) == 6
+    assert (
+        models_copy[0].spectral_model.model1.index
+        == models_copy[1].spectral_model.model1.model1.index
+    )
+    assert (
+        models_copy[0].spectral_model.model1.amplitude
+        == models_copy[1].spectral_model.model1.model1.amplitude
+    )
+
 
 def test_to_dict_not_default():
     model = PowerLawSpectralModel()
