@@ -51,8 +51,12 @@ def optimize_sherpa(parameters, function, store_trace=False, **kwargs):
     optimizer.config.update(kwargs)
 
     pars = [par.factor for par in parameters.free_parameters]
-    parmins = [par.factor_min for par in parameters.free_parameters]
-    parmaxes = [par.factor_max for par in parameters.free_parameters]
+    parmins = np.nan_to_num(
+        [par.factor_min for par in parameters.free_parameters], nan=-np.inf
+    )
+    parmaxes = np.nan_to_num(
+        [par.factor_max for par in parameters.free_parameters], nan=np.inf
+    )
 
     statfunc = SherpaLikelihood(function, parameters, store_trace)
 
