@@ -160,8 +160,9 @@ class CountsStatistic(abc.ABC):
     def compute_upper_limit(self, n_sigma=3):
         """Compute upper limit on the signal.
 
-        Searches the signal value for which the test statistics is n_sigma**2 away from the maximum
-        or from 0 if the measured excess is negative.
+        Searches the signal value for which the test statistic is n_sigma**2
+        away from the maximum.
+
 
         Parameters
         ----------
