@@ -4,12 +4,15 @@ from gammapy.stats.utils import sigma_to_ts, ts_to_sigma
 
 
 def test_sigma_ts_conversion():
-
     sigma_ref = 3
     ts_ref = 9
     df = 1
     ts = sigma_to_ts(3, df=df)
     assert_allclose(ts, ts_ref)
+    ts = sigma_to_ts(3, df=df)
+    assert_allclose(ts, ts_ref)
+    sigma = ts_to_sigma(ts, df=df)
+    assert_allclose(sigma, sigma_ref)
     sigma = ts_to_sigma(ts, df=df)
     assert_allclose(sigma, sigma_ref)
 
@@ -19,3 +22,11 @@ def test_sigma_ts_conversion():
     assert_allclose(ts, ts_ref)
     sigma = ts_to_sigma(ts, df=df)
     assert_allclose(sigma, sigma_ref)
+
+    sigma_ref = 3
+    ts_ref = 9
+    df = 1
+    ts = sigma_to_ts(3, df=df, n_sigma_asimov=3)
+    assert_allclose(ts, ts_ref)
+    sigma = ts_to_sigma(ts, df=df, ts_asimov=ts)
+    assert_allclose(sigma, sigma_ref)
