@@ -12,12 +12,12 @@ def trapz_loglog(y, x, axis=-1):
 
     Parameters
     ----------
-    y : array_like
+    y : `~numpy.ndarray`
         Input array to integrate.
-    x : array_like, optional
+    x : `~numpy.ndarray`
         Independent variable to integrate over.
     axis : int, optional
-        Specify the axis.
+        Specify the axis. Default is -1.
 
     Returns
     -------
