@@ -1,5 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""Utilities for progress bar display"""
+"""Utilities for progress bar display."""
 import logging
 
 log = logging.getLogger(__name__)
