@@ -1,14 +1,8 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import pytest
-from numpy.testing import assert_allclose
 import astropy.units as u
 from astropy.table import Column, Table
-from gammapy.utils.deprecation import GammapyDeprecationWarning
-from gammapy.utils.table import (
-    table_from_row_data,
-    table_row_to_dict,
-    table_standardise_units_copy,
-)
+from gammapy.utils.table import table_row_to_dict, table_standardise_units_copy
 
 
 def test_table_standardise_units():
@@ -40,14 +34,3 @@ def test_table_row_to_dict(table):
     actual = table_row_to_dict(table[1])
     expected = {"a": 2, "b": 2 * u.m, "c": "yy"}
     assert actual == expected
-
-
-def test_table_from_row_data():
-    rows = [dict(a=1, b=1 * u.m, c="x"), dict(a=2, b=2 * u.km, c="yy")]
-
-    with pytest.warns(GammapyDeprecationWarning):
-        table = table_from_row_data(rows)
-
-    assert isinstance(table, Table)
-    assert table["b"].unit == "m"
-    assert_allclose(table["b"].data, [1, 2000])
