@@ -1,18 +1,27 @@
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
 from .cmap import colormap_hess, colormap_milagro
 from .datasets import plot_npred_signal, plot_spectrum_datasets_off_regions
 from .heatmap import annotate_heatmap, plot_heatmap
 from .panel import MapPanelPlotter
-from .utils import plot_contour_line, plot_map_rgb, plot_theta_squared_table
+from .utils import (
+    add_colorbar,
+    plot_contour_line,
+    plot_distribution,
+    plot_map_rgb,
+    plot_theta_squared_table,
+)
 
 __all__ = [
     "annotate_heatmap",
     "colormap_hess",
     "colormap_milagro",
     "MapPanelPlotter",
+    "add_colorbar",
     "plot_contour_line",
     "plot_heatmap",
     "plot_map_rgb",
     "plot_spectrum_datasets_off_regions",
     "plot_theta_squared_table",
     "plot_npred_signal",
+    "plot_distribution",
 ]
