@@ -1,13 +1,12 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from numpy.testing import assert_allclose
-from gammapy.utils.testing import requires_dependency
 from gammapy.visualization import colormap_hess, colormap_milagro
 
 
 def _check_cmap_rgb_vals(vals, cmap, vmin=0, vmax=1):
     """Helper function to check RGB values of color images"""
-    from matplotlib.colors import Normalize
     from matplotlib.cm import ScalarMappable
+    from matplotlib.colors import Normalize
 
     norm = Normalize(vmin, vmax)
     sm = ScalarMappable(norm=norm, cmap=cmap)
@@ -16,7 +15,6 @@ def _check_cmap_rgb_vals(vals, cmap, vmin=0, vmax=1):
         assert_allclose(rgb_actual, rgb_expected, atol=1e-5)
 
 
-@requires_dependency("matplotlib")
 def test_colormap_hess():
     transition = 0.5
     cmap = colormap_hess(transition=transition)
@@ -30,7 +28,6 @@ def test_colormap_hess():
     _check_cmap_rgb_vals(vals, cmap)
 
 
-@requires_dependency("matplotlib")
 def test_colormap_milagro():
     transition = 0.5
     cmap = colormap_milagro(transition=transition)
